{*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 *}
{*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 *}

unit riegl.rdb.default.metadata;

{$WRITEABLECONST ON} // see section "initialization"

interface

// Meta data items definition version
const
  RDB_META_DATA_ITEMS_VERSION = '1.1.54';
  RDB_META_DATA_ITEMS_DATE = '2023-01-19';

// Meta data item states
const
  RDB_STATUS_REQUIRED = 1; // mandatory item
  RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
type
  TRDBPointcloudMetaDataItemInfo = record
    Name        : System.String;
    Title       : System.String;
    Description : System.String;
    Status      : System.Byte;
    Schema      : System.String;
    Example     : System.String;
  end;
  PRDBPointcloudMetaDataItemInfo = ^TRDBPointcloudMetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const
  RDB_RIEGL_ANGULAR_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.angular_notch_filter';
    Title       : 'Angular Notch Filter';
    Description : 'Angular notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Angular Notch Filter","type":"object","required":["angle","r'
      + 'ange_mean","amplitude_mean"],"$schema":"http://json-schema.org/draft-0'
      + '4/schema#","description":"Angular notch filter parameters for window '
      + 'glass echoes","properties":{"range_mean":{"items":{"type":"number"},"d'
      + 'escription":"Mean range [m]","type":"array"},"angle":{"items":{"type":'
      + '"number"},"description":"Angle [deg]","type":"array"},"amplitude_mean"'
      + ':{"items":{"type":"number"},"description":"Mean amplitude '
      + '[dB]","type":"array"}}}'
    );

    Example : (''
      + '{"range_mean":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0'
      + '.068,0.0675,0.06475],"angle":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,'
      + '22.0,23.0,24.0],"amplitude_mean":[3.780913,3.780913,3.480913,3.120913,'
      + '2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913]}'
    );
  );

// Atmospheric parameters
const
  RDB_RIEGL_ATMOSPHERE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.atmosphere';
    Title       : 'Atmosphere';
    Description : 'Atmospheric parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Atmospheric Parameters","type":"object","required":["tempera'
      + 'ture","pressure","rel_humidity","pressure_sl","amsl","group_velocity",'
      + '"attenuation","wavelength"],"$schema":"http://json-schema.org/draft-04'
      + '/schema#","description":"Atmospheric '
      + 'parameters","properties":{"pressure":{"description":"Pressure along '
      + 'measurment path '
      + '[mbar]","type":"number"},"wavelength":{"description":"Laser wavelength'
      + ' [nm]","type":"number"},"group_velocity":{"description":"Group '
      + 'velocity of laser beam '
      + '[m/s]","type":"number"},"rel_humidity":{"description":"Relative '
      + 'humidity along measurement path '
      + '[%]","type":"number"},"amsl":{"description":"Height above mean sea '
      + 'level (AMSL) '
      + '[m]","type":"number"},"temperature":{"description":"Temperature along '
      + 'measurement path '
      + '[\u00b0C]","type":"number"},"pressure_sl":{"description":"Atmospheric '
      + 'pressure at sea level '
      + '[mbar]","type":"number"},"attenuation":{"description":"Atmospheric '
      + 'attenuation [1/km]","type":"number"}}}'
    );

    Example : (''
      + '{"pressure":970,"wavelength":1550,"group_velocity":299711000.0,"rel_hu'
      + 'midity":63,"amsl":0,"temperature":7,"pressure_sl":970,"attenuation":0.'
      + '028125}'
    );
  );

// Laser beam geometry details
const
  RDB_RIEGL_BEAM_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.beam_geometry';
    Title       : 'Beam Geometry';
    Description : 'Laser beam geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Beam Geometry","type":"object","required":["beam_exit_diamet'
      + 'er","beam_divergence"],"$schema":"http://json-schema.org/draft-04/sche'
      + 'ma#","description":"Laser beam geometry details","properties":{"beam_d'
      + 'ivergence":{"exclusiveMinimum":false,"description":"Beam divergence in'
      + ' far field [rad]","type":"number","minimum":0},"beam_exit_diameter":{"'
      + 'exclusiveMinimum":false,"description":"Beam width at exit aperture '
      + '[m]","type":"number","minimum":0}}}'
    );

    Example : (''
      + '{"beam_divergence":0.0003,"beam_exit_diameter":0.0072}'
    );
  );

// List of control object type definitions
const
  RDB_RIEGL_CONTROL_OBJECT_CATALOG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_catalog';
    Title       : 'Control Object Catalog';
    Description : 'List of control object type definitions';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Control Object Catalog","type":"object","required":["types"]'
      + ',"definitions":{"round_corner_cube_prism":{"allOf":[{"$ref":"#/definit'
      + 'ions/common"},{"description":"round corner cube prism specific propert'
      + 'ies","properties":{"diameter":{"exclusiveMinimum":true,"description":"'
      + 'diameter in '
      + 'meters","type":"number","minimum":0},"shape":{"description":"shape ide'
      + 'ntifier","type":"string","enum":["round_corner_cube_prism"]},"offset":'
      + '{"description":"offset in meters, e.g. reflector constant (optional)",'
      + '"type":"number"}},"type":"object","required":["shape","diameter"]}],"d'
      + 'escription":"round corner cube prism","type":"object"},"checkerboard2x'
      + '2":{"allOf":[{"$ref":"#/definitions/common"},{"description":"checkerbo'
      + 'ard specific properties","properties":{"shape":{"description":"shape i'
      + 'dentifier","type":"string","enum":["checkerboard2x2"]},"square_length"'
      + ':{"exclusiveMinimum":true,"description":"length of a square of the '
      + 'checkerboard in meters","type":"number","minimum":0}},"type":"object",'
      + '"required":["shape","square_length"]}],"description":"checkerboard 2 '
      + 'by 2","type":"object"},"cylinder":{"allOf":[{"$ref":"#/definitions/com'
      + 'mon"},{"description":"cylinder specific properties","properties":{"hei'
      + 'ght":{"exclusiveMinimum":true,"description":"height in meters","type":'
      + '"number","minimum":0},"diameter":{"exclusiveMinimum":true,"description'
      + '":"diameter in '
      + 'meters","type":"number","minimum":0},"shape":{"description":"shape ide'
      + 'ntifier","type":"string","enum":["cylinder"]}},"type":"object","requir'
      + 'ed":["shape","diameter","height"]}],"description":"cylinder","type":"o'
      + 'bject"},"circular_disk":{"allOf":[{"$ref":"#/definitions/common"},{"de'
      + 'scription":"circular disk specific properties","properties":{"diameter'
      + '":{"exclusiveMinimum":true,"description":"diameter in '
      + 'meters","type":"number","minimum":0},"shape":{"description":"shape ide'
      + 'ntifier","type":"string","enum":["circular_disk"]},"offset":{"descript'
      + 'ion":"offset in meters, e.g. reflector constant (optional)","type":"nu'
      + 'mber"}},"type":"object","required":["shape","diameter"]}],"description'
      + '":"circular disk","type":"object"},"rectangle":{"allOf":[{"$ref":"#/de'
      + 'finitions/common"},{"description":"rectangle specific properties","pro'
      + 'perties":{"length":{"exclusiveMinimum":true,"description":"length in m'
      + 'eters","type":"number","minimum":0},"shape":{"enum":["rectangle"],"typ'
      + 'e":"string"},"width":{"exclusiveMinimum":true,"description":"width in '
      + 'meters","type":"number","minimum":0}},"type":"object","required":["sha'
      + 'pe","length","width"]}],"description":"rectangle","type":"object"},"co'
      + 'mmon":{"description":"common object '
      + 'properties","properties":{"surface_type":{"description":"surface '
      + 'material type","type":"string","enum":["retro_reflective_foil","diffus'
      + 'e"]},"description":{"description":"string describing the '
      + 'object","type":"string"},"name":{"description":"unique type identifier'
      + '","type":"string","minLength":3},"shape":{"description":"shape identif'
      + 'ier","type":"string","enum":["rectangle","checkerboard2x2","chevron","'
      + 'circular_disk","cylinder","sphere","round_corner_cube_prism"]}},"type"'
      + ':"object","required":["name","shape"]},"chevron":{"allOf":[{"$ref":"#/'
      + 'definitions/common"},{"description":"chevron specific properties","pro'
      + 'perties":{"outside_edge_length":{"exclusiveMinimum":true,"description"'
      + ':"length of the two outer edges in meters","type":"number","minimum":0'
      + '},"thickness":{"exclusiveMinimum":true,"description":"thickness in '
      + 'meters","type":"number","minimum":0},"shape":{"description":"shape ide'
      + 'ntifier","type":"string","enum":["chevron"]}},"type":"object","require'
      + 'd":["shape","outside_edge_length","thickness"]}],"description":"chevro'
      + 'n","type":"object"},"sphere":{"allOf":[{"$ref":"#/definitions/common"}'
      + ',{"description":"sphere specific properties","properties":{"diameter":'
      + '{"exclusiveMinimum":true,"description":"diameter in '
      + 'meters","type":"number","minimum":0},"shape":{"description":"shape ide'
      + 'ntifier","type":"string","enum":["sphere"]}},"type":"object","required'
      + '":["shape","diameter"]}],"description":"sphere","type":"object"}},"$sc'
      + 'hema":"http://json-schema.org/draft-04/schema#","description":"List of'
      + ' control object type definitions","properties":{"types":{"items":{"typ'
      + 'e":"object","oneOf":[{"$ref":"#/definitions/rectangle"},{"$ref":"#/def'
      + 'initions/checkerboard2x2"},{"$ref":"#/definitions/chevron"},{"$ref":"#'
      + '/definitions/circular_disk"},{"$ref":"#/definitions/cylinder"},{"$ref"'
      + ':"#/definitions/sphere"},{"$ref":"#/definitions/round_corner_cube_pris'
      + 'm"}]},"uniqueItems":true,"type":"array"}}}'
    );

    Example : (''
      + '{"types":[{"width":0.3,"description":"Rectangle (60cm x '
      + '30cm)","length":0.6,"name":"Rectangle '
      + '60x30","shape":"rectangle"},{"width":0.4,"description":"Rectangle '
      + '(80cm x 40cm)","length":0.8,"name":"Rectangle '
      + '80x40","shape":"rectangle"},{"description":"Checkerboard (square '
      + 'length: 30cm)","name":"Checkerboard2x2 30","square_length":0.3,"shape"'
      + ':"checkerboard2x2"},{"description":"Checkerboard (square length: '
      + '50cm)","name":"Checkerboard2x2 50","square_length":0.5,"shape":"checke'
      + 'rboard2x2"},{"thickness":0.1016,"description":"Chevron (a=24''''; '
      + 'b=4'''')","outside_edge_length":0.6096,"name":"Chevron '
      + '24''''/4''''","shape":"chevron"},{"surface_type":"diffuse","description":"'
      + ' Circular Disk (diameter: 50cm)","diameter":0.5,"name":"Circular Disk '
      + '50","shape":"circular_disk"},{"surface_type":"retro_reflective_foil","'
      + 'diameter":0.05,"name":"RIEGL flat reflector 50 mm","description":"flat'
      + ' circular reflector from retro-reflective foil","offset":0.0,"shape":"'
      + 'circular_disk"},{"surface_type":"retro_reflective_foil","diameter":0.1'
      + ',"name":"RIEGL flat reflector 100 mm","description":"flat circular '
      + 'reflector from retro-reflective foil","offset":0.0,"shape":"circular_d'
      + 'isk"},{"surface_type":"retro_reflective_foil","diameter":0.15,"name":"'
      + 'RIEGL flat reflector 150 mm","description":"flat circular reflector '
      + 'from retro-reflective foil","offset":0.0,"shape":"circular_disk"},{"su'
      + 'rface_type":"retro_reflective_foil","height":0.05,"diameter":0.05,"nam'
      + 'e":"RIEGL cylindrical reflector 50 mm","description":"cylindrical '
      + 'reflector from retro-reflective foil","shape":"cylinder"},{"surface_ty'
      + 'pe":"retro_reflective_foil","height":0.1,"diameter":0.1,"name":"RIEGL '
      + 'cylindrical reflector 100 mm","description":"cylindrical reflector '
      + 'from retro-reflective foil","shape":"cylinder"},{"description":"Sphere'
      + ' (diameter: 200 mm)","diameter":0.2,"name":"Sphere 200 '
      + 'mm","shape":"sphere"},{"offset":0.0,"description":"round corner cube '
      + 'prism","diameter":0.05,"name":"Corner Cube Prism 50 '
      + 'mm","shape":"round_corner_cube_prism"}],"comments":["This file '
      + 'contains a list of control object types (aka. ''catalog'').","Each type '
      + 'is described by an object,","which must contain at least the following'
      + ' parameters:","  - name: unique identifier of the type","  - shape: '
      + 'one of the following supported shapes:","      - rectangle","      - '
      + 'checkerboard2x2","      - chevron","      - circular_disk","      - '
      + 'cylinder","      - sphere","      - '
      + 'round_corner_cube_prism","Depending on ''shape'', the following '
      + 'parameters must/may be specified:","  - rectangle:","      - length: '
      + 'length in meters","      - width: width in meters","  - '
      + 'checkerboard2x2:","      - square_length: length of a square of the '
      + 'checkerboard in meters","  - circular_disk:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","  - chevron:","      - outside_edge_length: '
      + 'length of the two outer edges in meters","      - thickness: thickness'
      + ' in meters","  - cylinder:","      - diameter: diameter in meters","'
      + '      - height: height in meters","  - sphere:","      - diameter: '
      + 'diameter in meters","  - round_corner_cube_prism:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","Optional parameters:","    - description: string'
      + ' describing the object","    - surface_type: surface material type '
      + '(either ''retro_reflective_foil'' or ''diffuse'')"]}'
    );
  );

// Details about the control object reference file
const
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_reference_file';
    Title       : 'Control Object Reference file';
    Description : 'Details about the control object reference file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"De'
      + 'tails about the control object reference file","title":"Control Object'
      + ' Reference file","type":"object","properties":{"reference_file":{"desc'
      + 'ription":"Reference to a control object '
      + 'file","properties":{"file_path":{"description":"Path of the control '
      + 'object file relative to referring '
      + 'file","type":"string"},"file_uuid":{"description":"Control object '
      + 'file''s Universally Unique Identifier (RFC 4122)","type":"string"}},"ty'
      + 'pe":"object","required":["file_uuid","file_path"]}}}'
    );

    Example : (''
      + '{"reference_file":{"file_path":"../../../10_CONTROL_OBJECTS/ControlPoi'
      + 'nts.cpx","file_uuid":"810f5d57-eccf-49ed-b07a-0cdd109b4213"}}'
    );
  );

// Detection probability as a function of amplitude
const
  RDB_RIEGL_DETECTION_PROBABILITY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.detection_probability';
    Title       : 'Detection Probability';
    Description : 'Detection probability as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Detection Probability","type":"object","required":["amplitud'
      + 'e","detection_probability"],"$schema":"http://json-schema.org/draft-04'
      + '/schema#","description":"Detection probability as a function of amplit'
      + 'ude","properties":{"amplitude":{"items":{"type":"number"},"description'
      + '":"Amplitude [dB]","type":"array"},"detection_probability":{"items":{"'
      + 'type":"number"},"description":"Detection probability '
      + '[0..1]","type":"array"}}}'
    );

    Example : (''
      + '{"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],"detection'
      + '_probability":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]}'
    );
  );

// Details about the device used to acquire the point cloud
const
  RDB_RIEGL_DEVICE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device';
    Title       : 'Device Information';
    Description : 'Details about the device used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Device Information","type":"object","required":["device_type'
      + '","serial_number"],"$schema":"http://json-schema.org/draft-04/schema#"'
      + ',"description":"Details about the device used to acquire the point '
      + 'cloud","properties":{"serial_number":{"description":"Device serial '
      + 'number (e.g. '
      + 'S2221234)","type":"string"},"device_type":{"description":"Device type '
      + 'identifier (e.g. '
      + 'VZ-400i)","type":"string"},"channel_text":{"description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel '
      + 'devices)","type":"string"},"device_name":{"description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner '
      + 'systems)","type":"string"},"device_build":{"description":"Device build'
      + ' variant","type":"string"},"channel_number":{"exclusiveMinimum":false,'
      + '"description":"Laser channel number (not defined or 0: single channel '
      + 'device)","type":"integer","minimum":0}}}'
    );

    Example : (''
      + '{"serial_number":"S2221234","device_type":"VZ-400i","channel_text":"",'
      + '"device_name":"Scanner 1","device_build":"","channel_number":0}'
    );
  );

// Scanner device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry';
    Title       : 'Device Geometry';
    Description : 'Scanner device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Device Geometry","type":"object","required":["primary"],"$sc'
      + 'hema":"http://json-schema.org/draft-04/schema#","description":"Scanner'
      + ' device geometry details","properties":{"amu":{"description":"Angle '
      + 'Measurement Unit","properties":{"lineCC":{"exclusiveMinimum":false,"de'
      + 'scription":"Line Circle Count (number of LSBs per full rotation about '
      + 'line axis)","type":"number","minimum":0},"frameCC":{"exclusiveMinimum"'
      + ':false,"description":"Frame Circle Count (number of LSBs per full '
      + 'rotation about frame axis)","type":"number","minimum":0}},"type":"obje'
      + 'ct"},"primary":{"description":"Primary device geometry structure (mand'
      + 'atory)","properties":{"ID":{"items":{"type":"integer"},"description":"'
      + 'Structure identifier","maxItems":2,"type":"array","minItems":2},"conte'
      + 'nt":{"items":{"type":"number"},"description":"Internal calibration val'
      + 'ues","type":"array"}},"type":"object","required":["ID","content"]},"se'
      + 'condary":{"description":"Additional device geometry structure (optiona'
      + 'l)","properties":{"ID":{"items":{"type":"integer"},"description":"Stru'
      + 'cture identifier","maxItems":2,"type":"array","minItems":2},"content":'
      + '{"items":{"type":"number"},"description":"Internal calibration values"'
      + ',"type":"array"}},"type":"object","required":["ID","content"]}}}'
    );

    Example : (''
      + '{"amu":{"lineCC":124000,"frameCC":124000},"primary":{"ID":[4,0],"conte'
      + 'nt":[0]},"secondary":{"ID":[91,0],"content":[0]}}'
    );
  );

// Scanner passive channel device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry_passive_channel';
    Title       : 'Device Geometry Passive Channel';
    Description : 'Scanner passive channel device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Device Geometry Passive Channel","type":"object","required":'
      + '["primary"],"$schema":"http://json-schema.org/draft-04/schema#","descr'
      + 'iption":"Scanner passive channel device geometry '
      + 'details","properties":{"primary":{"description":"Primary device '
      + 'geometry structure (mandatory)","properties":{"ID":{"items":{"type":"i'
      + 'nteger"},"description":"Structure identifier","maxItems":2,"type":"arr'
      + 'ay","minItems":2},"content":{"items":{"type":"number"},"description":"'
      + 'Internal calibration values","type":"array"}},"type":"object","require'
      + 'd":["ID","content"]}}}'
    );

    Example : (''
      + '{"primary":{"ID":[143,0],"content":[0]}}'
    );
  );

// Limits of the measured values output by the device
const
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_output_limits';
    Title       : 'Device Output Limits';
    Description : 'Limits of the measured values output by the device';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"Li'
      + 'mits of the measured values output by the device. The limits depend on'
      + ' the device type, measurement program and/or scan '
      + 'pattern.","title":"Device Output Limits","type":"object","properties":'
      + '{"background_radiation_minimum":{"description":"Minimum possible '
      + 'background radiation.","type":"number"},"background_radiation_maximum"'
      + ':{"description":"Maximum possible background '
      + 'radiation.","type":"number"},"range_minimum":{"description":"Minimum '
      + 'possible range in meters.","type":"number"},"mta_zone_count_maximum":{'
      + '"description":"Maximum number of MTA '
      + 'zones.","type":"number"},"reflectance_minimum":{"description":"Minimum'
      + ' possible reflectance in '
      + 'dB.","type":"number"},"reflectance_maximum":{"description":"Maximum '
      + 'possible reflectance in '
      + 'dB.","type":"number"},"amplitude_minimum":{"description":"Minimum '
      + 'possible amplitude in '
      + 'dB.","type":"number"},"range_maximum":{"description":"Maximum possible'
      + ' range in '
      + 'meters.","type":"number"},"echo_count_maximum":{"description":"Maximum'
      + ' number of echoes a laser shot can '
      + 'have.","type":"number"},"deviation_minimum":{"description":"Minimum '
      + 'possible pulse shape deviation.","type":"number"},"amplitude_maximum":'
      + '{"description":"Maximum possible amplitude in '
      + 'dB.","type":"number"},"deviation_maximum":{"description":"Maximum '
      + 'possible pulse shape deviation.","type":"number"}}}'
    );

    Example : (''
      + '{"amplitude_minimum":0.0,"background_radiation_maximum":0,"range_maxim'
      + 'um":10000.0,"mta_zone_count_maximum":7,"range_minimum":2.9,"deviation_'
      + 'minimum":-1,"background_radiation_minimum":0,"deviation_maximum":32767'
      + ',"reflectance_minimum":-100.0,"amplitude_maximum":100.0,"reflectance_m'
      + 'aximum":100.0}'
    );
  );

// Details about the devices used to acquire the point cloud
const
  RDB_RIEGL_DEVICES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.devices';
    Title       : 'Devices Information';
    Description : 'Details about the devices used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"De'
      + 'tails about the devices used to acquire the point cloud (e.g. when '
      + 'merging point clouds of different devices)","title":"Devices Informati'
      + 'on","type":"array","items":{"properties":{"serial_number":{"descriptio'
      + 'n":"Device serial number (e.g. '
      + 'S2221234)","type":"string"},"device_type":{"description":"Device type '
      + 'identifier (e.g. '
      + 'VZ-400i)","type":"string"},"channel_text":{"description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel '
      + 'devices)","type":"string"},"device_name":{"description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner '
      + 'systems)","type":"string"},"device_build":{"description":"Device build'
      + ' variant","type":"string"},"signed":{"description":"Flag that is set '
      + 'when the original ''riegl.device'' entry in the source file was '
      + 'correctly signed.","type":"boolean"},"channel_number":{"exclusiveMinim'
      + 'um":false,"description":"Laser channel number (not defined or 0: '
      + 'single channel device)","type":"integer","minimum":0}},"type":"object"'
      + ',"required":["device_type","serial_number"]}}'
    );

    Example : (''
      + '[{"serial_number":"S2221234","device_type":"VZ-400i","channel_text":""'
      + ',"device_name":"Scanner 1","device_build":"","signed":false,"channel_n'
      + 'umber":0},{"serial_number":"S2222680","device_type":"VQ-1560i-DW","cha'
      + 'nnel_text":"","device_name":"Scanner 2","device_build":"","signed":tru'
      + 'e,"channel_number":1},{"serial_number":"S2222680","device_type":"VQ-15'
      + '60i-DW","channel_text":"","device_name":"Scanner '
      + '3","device_build":"","signed":true,"channel_number":2}]'
    );
  );

// Dyntrig
const
  RDB_RIEGL_DYNTRIG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.dyntrig';
    Title       : 'Dyntrig';
    Description : 'Dyntrig';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"Dy'
      + 'ntrig","title":"Dyntrig","properties":{"scale":{"description":"Scale '
      + 'in units of dB, for calculation of line: line number N=(amplitude-offs'
      + 'et)/scale","type":"number"},"pre":{"description":"Dyntrig pre '
      + 'values","properties":{"nc":{"maximum":255,"description":"Number of ent'
      + 'ries","type":"integer","minimum":0},"a":{"items":{"type":"number"},"de'
      + 'scription":"...","maxItems":2080,"type":"array","minItems":1}},"type":'
      + '"object","required":["nc","a"]},"post":{"description":"Dyntrig post '
      + 'values","properties":{"nc":{"maximum":255,"description":"Number of ent'
      + 'ries","type":"integer","minimum":0},"a":{"items":{"type":"number"},"de'
      + 'scription":"...","maxItems":2080,"type":"array","minItems":1}},"type":'
      + '"object","required":["nc","a"]},"offset":{"description":"Offset in '
      + 'units of dB, for calculation of line","type":"number"},"tab":{"items":'
      + '{"description":"...","properties":{"dec2":{"description":"Rise of '
      + 'pre-trigger threshold after del2 in units of '
      + 'dB/m","type":"number"},"del1":{"description":"Length of constant '
      + 'post-trigger threshold elevation in units of '
      + 'm","type":"number"},"thra1":{"description":"Post-trigger threshold in '
      + 'units of dB","type":"number"},"dec1":{"description":"Decay of '
      + 'post-trigger threshold after del1 in units of '
      + 'dB/m","type":"number"},"del2":{"description":"Length of constant '
      + 'pre-trigger threshold elevation in units of '
      + 'm","type":"number"},"thra2":{"description":"Pre-trigger threshold in '
      + 'units of dB","type":"number"}},"type":"object","required":["thra1","de'
      + 'l1","dec1","thra2","del2","dec2"]},"description":"...","maxItems":128,'
      + '"type":"array","minItems":1}}}'
    );

    Example : (''
      + '{"scale":1.0,"pre":{"nc":128,"a":[78,86,126,134,31]},"post":{"nc":128,'
      + '"a":[78,86,126,134,31]},"offset":0.0,"tab":[{"dec2":0.0,"del1":0.0,"th'
      + 'ra1":0.0,"dec1":0.0,"del2":0.0,"thra2":0.0}]}'
    );
  );

// Details about echo files
const
  RDB_RIEGL_ECHO_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.echo_info';
    Title       : 'Echo Information';
    Description : 'Details about echo files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Echo Information","type":"object","required":["echo_file"],"'
      + '$schema":"http://json-schema.org/draft-04/schema#","description":"Deta'
      + 'ils about echo files","properties":{"echo_file":{"properties":{"file_e'
      + 'xtension":{"description":"Echo file extension, without the leading '
      + 'dot","type":"string"},"file_uuid":{"description":"File''s Universally '
      + 'Unique Identifier (RFC 4122)","type":"string"}},"type":"object","requi'
      + 'red":["file_extension"]}}}'
    );

    Example : (''
      + '{"echo_file":{"file_extension":"owp","file_uuid":"26a03615-67c0-4bea-8'
      + 'fe8-c577378fe661"}}'
    );
  );

// Details for exponential decomposition of full waveform data
const
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.exponential_decomposition';
    Title       : 'Exponential Decomposition';
    Description : 'Details for exponential decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"additionalProperties":false,"title":"Exponential Decomposition","typ'
      + 'e":"object","definitions":{"channel":{"properties":{"scale":{"descript'
      + 'ion":"amplitude '
      + 'calibration","type":"number"},"delay":{"description":"delay '
      + 'calibration in seconds","type":"number"},"a_lin":{"exclusiveMinimum":f'
      + 'alse,"type":"number","maximum":1,"description":"relative linear '
      + 'amplitude range [0..1]","minimum":0,"exclusiveMaximum":false},"paramet'
      + 'er":{"description":"parameters of the syswave exponential '
      + 'sum","properties":{"A":{"items":{"type":"number"},"description":"real '
      + 'part of amplitude factor in units of full-scale","type":"array"},"B":{'
      + '"items":{"type":"number"},"description":"imaginary part of amplitude '
      + 'factor in units of full-scale","type":"array"},"gamma":{"items":{"type'
      + '":"number"},"description":"decay in 1/second","type":"array"},"omega":'
      + '{"items":{"type":"number"},"description":"angular frequency in Hz","ty'
      + 'pe":"array"}},"type":"object","required":["A","B","gamma","omega"]}},"'
      + 'type":"object","required":["delay","scale","parameter"]}},"$schema":"h'
      + 'ttp://json-schema.org/draft-04/schema#","description":"Details for '
      + 'exponential decomposition of full waveform data","patternProperties":{'
      + '"^[0-9]+$":{"$ref":"#/definitions/channel","description":"one field '
      + 'per channel, field name is channel index"}}}'
    );

    Example : (''
      + '{"0":{"scale":1.0,"delay":3.783458418887631e-09,"a_lin":0.27,"paramete'
      + 'r":{"A":[0.9772450923919678,0.3354335129261017,-1.312678575515747],"B"'
      + ':[-3.9813032150268555,0.08622030913829803,-0.3152860999107361],"gamma"'
      + ':[-1094726528.0,-769562752.0,-848000064.0],"omega":[352020896.0,364792'
      + '7552.0,-1977987072.0]}},"1":{"scale":1.0,"delay":3.5e-09,"a_lin":0.9,"'
      + 'parameter":{"A":[0.9,0.3,-1.3],"B":[-3.9,0.0,-0.3],"gamma":[-109472652'
      + '8.0,-769562752.0,-848000064.0],"omega":[352020896.0,3647927552.0,-1977'
      + '987072.0]}}}'
    );
  );

// Details for Gaussian decomposition of full waveform data
const
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.gaussian_decomposition';
    Title       : 'Gaussian Decomposition';
    Description : 'Details for Gaussian decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Gaussian Decomposition","type":"object","required":["amplitu'
      + 'de_lsb_low_power","amplitude_lsb_high_power","amplitude_db","range_off'
      + 'set_sec_low_power","range_offset_sec_high_power"],"$schema":"http://js'
      + 'on-schema.org/draft-04/schema#","description":"riegl.gaussian_decompos'
      + 'ition contains information relevant for extracting calibrated '
      + 'amplitudes and calibrated ranges from a Gaussian decomposition of full'
      + ' waveform data. This information is contained in a table with five '
      + 'columns. Two columns are to be used as input: amplitude_lsb_low_power '
      + 'and amplitude_lsb_high_power. The other three columns provide the '
      + 'outputs. Amplitude_db gives the calibrated amplitude in the optical '
      + 'regime in decibels. The range offset columns provide additive range '
      + 'offsets, given in units of seconds, for each channel.","properties":{"'
      + 'amplitude_lsb_high_power":{"items":{"type":"number"},"type":"array"},"'
      + 'amplitude_lsb_low_power":{"items":{"type":"number"},"type":"array"},"r'
      + 'ange_offset_sec_low_power":{"items":{"type":"number"},"type":"array"},'
      + '"amplitude_db":{"items":{"type":"number"},"type":"array"},"range_offse'
      + 't_sec_high_power":{"items":{"type":"number"},"type":"array"}}}'
    );

    Example : (''
      + '{"amplitude_lsb_high_power":[],"amplitude_lsb_low_power":[],"range_off'
      + 'set_sec_low_power":[],"amplitude_db":[],"range_offset_sec_high_power":'
      + '[]}'
    );
  );

// Point cloud georeferencing information
const
  RDB_RIEGL_GEO_TAG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geo_tag';
    Title       : 'Geo Tag';
    Description : 'Point cloud georeferencing information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"Po'
      + 'int cloud georeferencing information","title":"Geo '
      + 'Tag","type":"object","properties":{"crs":{"description":"Global '
      + 'Coordinate Reference System. Please note that only 3D Cartesian '
      + 'Coordinate Systems are '
      + 'allowed.","properties":{"wkt":{"description":"\"Well-Known Text\" '
      + 'string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w'
      + 'kt-crs)","type":"string"},"name":{"description":"Coordinate reference '
      + 'system name","type":"string"},"epsg":{"description":"EPSG code","type"'
      + ':"integer","minimum":0}},"type":"object"},"pose":{"items":{"items":{"d'
      + 'escription":"columns","type":"number"},"description":"rows","type":"ar'
      + 'ray","minItems":4,"maxItems":4},"description":"Coordinate '
      + 'Transformation Matrix to transform from File Coordinate System to '
      + 'Global Coordinate Reference System. 4x4 matrix stored as two '
      + 'dimensional array, row major '
      + 'order.","type":"array","minItems":4,"maxItems":4}}}'
    );

    Example : (''
      + '{"crs":{"wkt":"GEOCCS[\"WGS84 Geocentric\",DATUM[\"WGS84\",SPHEROID[\"'
      + 'WGS84\",6378137.000,298.257223563,AUTHORITY[\"EPSG\",\"7030\"]],AUTHOR'
      + 'ITY[\"EPSG\",\"6326\"]],PRIMEM[\"Greenwich\",0.0000000000000000,AUTHOR'
      + 'ITY[\"EPSG\",\"8901\"]],UNIT[\"Meter\",1.00000000000000000000,AUTHORIT'
      + 'Y[\"EPSG\",\"9001\"]],AXIS[\"X\",OTHER],AXIS[\"Y\",EAST],AXIS[\"Z\",NO'
      + 'RTH],AUTHORITY[\"EPSG\",\"4978\"]]","name":"WGS84 Geocentric","epsg":4'
      + '978},"pose":[[-0.269827776749716,-0.723017716139738,0.635954678449952,'
      + '4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847'
      + ',1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196'
      + '],[0.0,0.0,0.0,1.0]]}'
    );
  );

// Geometric scale factor applied to point coordinates
const
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geometric_scale_factor';
    Title       : 'Geometric Scale Factor';
    Description : 'Geometric scale factor applied to point coordinates';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"Ge'
      + 'ometric scale factor applied to point '
      + 'coordinates","type":"number","minimum":0,"exclusiveMinimum":true}'
    );

    Example : (''
      + '1.0'
    );
  );

// Parameters used for georeferencing of the point cloud
const
  RDB_RIEGL_GEOREFERENCING_PARAMETERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.georeferencing_parameters';
    Title       : 'Georeferencing Parameters';
    Description : 'Parameters used for georeferencing of the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"Pa'
      + 'rameters used for georeferencing of the point '
      + 'cloud","title":"Georeferencing Parameters","type":"object","properties'
      + '":{"trajectory_offsets":{"description":"Correction offsets applied to '
      + 'the trajectory data","properties":{"offset_yaw":{"description":"[deg]"'
      + ',"type":"number"},"version":{"description":"Meaning of offset values '
      + 'and how to apply them; version 0: '
      + 'Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), '
      + 'version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch'
      + ')*Rx(offset_roll)","type":"integer"},"offset_pitch":{"description":"[d'
      + 'eg]","type":"number"},"offset_time":{"description":"[s]","type":"numbe'
      + 'r"},"offset_east":{"description":"[m]","type":"number"},"offset_roll":'
      + '{"description":"[deg]","type":"number"},"offset_north":{"description":'
      + '"[m]","type":"number"},"offset_height":{"description":"[m]","type":"nu'
      + 'mber"}},"type":"object"},"trajectory_file":{"description":"Trajectory '
      + 'data used for georeferencing of the point '
      + 'cloud","properties":{"file_extension":{"description":"Trajectory file '
      + 'extension, without the leading '
      + 'dot","type":"string"},"file_uuid":{"description":"File''s Universally '
      + 'Unique Identifier (RFC 4122)","type":"string"}},"type":"object","requi'
      + 'red":["file_extension"]},"body_coordinate_system_type":{"description":'
      + '"BODY coordinate frame (NED: North-East-Down, ENU: East-North-Up), '
      + 'default: NED","type":"string","enum":["NED","ENU"]},"socs_to_body_matr'
      + 'ix":{"items":{"items":{"description":"columns","type":"number"},"descr'
      + 'iption":"rows","type":"array","minItems":4,"maxItems":4},"description"'
      + ':"Coordinate Transformation Matrix to transform from Scanner''s Own '
      + 'Coordinate System to Body Coordinate System. 4x4 matrix stored as two '
      + 'dimensional array, row major order.","type":"array","minItems":4,"maxI'
      + 'tems":4},"socs_to_rocs_matrix":{"items":{"items":{"description":"colum'
      + 'ns","type":"number"},"description":"rows","type":"array","minItems":4,'
      + '"maxItems":4},"description":"Coordinate Transformation Matrix to '
      + 'transform from Scanner''s Own Coordinate System to Record Coordinate '
      + 'System. 4x4 matrix stored as two dimensional array, row major '
      + 'order.","type":"array","minItems":4,"maxItems":4}}}'
    );

    Example : (''
      + '{"trajectory_offsets":{"offset_yaw":-0.45,"version":0,"offset_pitch":0'
      + '.01,"offset_time":18.007,"offset_east":0.15,"offset_roll":0.03,"offset'
      + '_north":0.07,"offset_height":-0.2},"trajectory_file":{"file_extension"'
      + ':"pofx","file_uuid":"93a03615-66c0-4bea-8ff8-c577378fe660"},"body_coor'
      + 'dinate_system_type":"NED","socs_to_body_matrix":[[-0.269827776749716,-'
      + '0.723017716139738,0.635954678449952,0.0],[0.962908599449764,-0.2026051'
      + '7250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.7508684796801,'
      + '0.0],[0.0,0.0,0.0,1.0]]}'
    );
  );

// Map of item names
const
  RDB_RIEGL_ITEM_NAMES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.item_names';
    Title       : 'Item Names';
    Description : 'Map of item names';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"additionalProperties":false,"title":"Item Names","type":"object","$s'
      + 'chema":"http://json-schema.org/draft-04/schema#","description":"Map of'
      + ' item names","patternProperties":{"^-?[0-9]+$":{"description":"One '
      + 'field per item, field name is item id, field value is item '
      + 'name","type":"string"}}}'
    );

    Example : (''
      + '{"47":"Name of item with id 47","2":"Name of item with id 2","1":"Name'
      + ' of item with id 1","-1":"Name of item with id -1"}'
    );
  );

// License keys for software features
const
  RDB_RIEGL_LICENSES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.licenses';
    Title       : 'Software License Keys';
    Description : 'License keys for software features';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"additionalProperties":false,"title":"Software License Keys","type":"'
      + 'object","$schema":"http://json-schema.org/draft-04/schema#","descripti'
      + 'on":"License keys for software '
      + 'features","patternProperties":{"^.*$":{"items":{"description":"License'
      + ' key (example: ''46AE032A - 39882AC4 - 9EC0A184 - '
      + '6F163D73'')","type":"string"},"description":"Each field of the object '
      + 'represents a feature and holds a list of license keys, where the field'
      + ' name is the feature name.","type":"array","minItems":1}}}'
    );

    Example : (''
      + '{"Full Waveform Analysis Topography":["0FD5FF07 - 011A1255 - 9F76CACA '
      + '- 8D2ED557"],"MTA resolution":["468E020A - 39A922E4 - B681A184 - '
      + '673E3D72"],"Full Waveform Analysis Topography with GPU '
      + 'support":["8AB44126 - 23B92250 - 16E2689F - '
      + '34EF7E7B"],"Georeferencing":["46AE032A - 39882AC4 - 9EC0A184 - '
      + '6F163D73"]}'
    );
  );

// Parameters for MTA processing
const
  RDB_RIEGL_MTA_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.mta_settings';
    Title       : 'MTA Settings';
    Description : 'Parameters for MTA processing';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"Pa'
      + 'rameters for MTA processing","title":"MTA Settings","type":"object","p'
      + 'roperties":{"zone_count":{"maximum":255,"description":"Maximum number '
      + 'of MTA zones.","type":"integer","minimum":0},"modulation_depth":{"desc'
      + 'ription":"Depth of pulse position modulation in meter.","type":"number'
      + '","minimum":0},"zone_width":{"description":"Width of a MTA zone in '
      + 'meter.","type":"number","minimum":0}}}'
    );

    Example : (''
      + '{"zone_count":23,"modulation_depth":9.368514,"zone_width":149.896225}'
    );
  );

// Lookup table for range correction based on raw range
const
  RDB_RIEGL_NEAR_RANGE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.near_range_correction';
    Title       : 'Near Range Correction Table';
    Description : 'Lookup table for range correction based on raw range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Near Range Correction Table","type":"object","required":["de'
      + 'lta","content"],"$schema":"http://json-schema.org/draft-04/schema#","d'
      + 'escription":"Lookup table for range correction based on raw range","pr'
      + 'operties":{"content":{"items":{"type":"number"},"description":"Correct'
      + 'ion value [m] to be added to the raw range","maxItems":2000,"type":"ar'
      + 'ray","minItems":1},"delta":{"description":"Delta between table entries'
      + ' [m], first entry is at range = 0 m","type":"number"}}}'
    );

    Example : (''
      + '{"content":[0.0],"delta":0.512}'
    );
  );

// Standard deviation for range and amplitude as a function of amplitude
const
  RDB_RIEGL_NOISE_ESTIMATES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.noise_estimates';
    Title       : 'Noise Estimates';
    Description : 'Standard deviation for range and amplitude as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Noise Estimates","type":"object","required":["amplitude","ra'
      + 'nge_sigma","amplitude_sigma"],"$schema":"http://json-schema.org/draft-'
      + '04/schema#","description":"Standard deviation for range and amplitude '
      + 'as a function of amplitude","properties":{"amplitude":{"items":{"type"'
      + ':"number"},"description":"Amplitude [dB]","type":"array"},"range_sigma'
      + '":{"items":{"type":"number"},"description":"Sigma range [m]","type":"a'
      + 'rray"},"amplitude_sigma":{"items":{"type":"number"},"description":"Sig'
      + 'ma amplitude [dB]","type":"array"}}}'
    );

    Example : (''
      + '{"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],"range_sig'
      + 'ma":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,0.016,0.014'
      + '],"amplitude_sigma":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.'
      + '432,0.39,0.354]}'
    );
  );

// Notch filter parameters for window glass echoes
const
  RDB_RIEGL_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.notch_filter';
    Title       : 'Notch Filter';
    Description : 'Notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Notch Filter","type":"object","required":["range_minimum","r'
      + 'ange_maximum","amplitude_maximum"],"$schema":"http://json-schema.org/d'
      + 'raft-04/schema#","description":"Notch filter parameters for window '
      + 'glass echoes","properties":{"range_minimum":{"description":"Minimum '
      + 'range '
      + '[m]","type":"number"},"amplitude_maximum":{"description":"Maximum '
      + 'amplitude [dB]","type":"number","minimum":0},"range_maximum":{"descrip'
      + 'tion":"Maximum range [m]","type":"number"}}}'
    );

    Example : (''
      + '{"range_minimum":-0.5,"amplitude_maximum":18.0,"range_maximum":0.2}'
    );
  );

// Details about the pixels contained in the file
const
  RDB_RIEGL_PIXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pixel_info';
    Title       : 'Pixel Information';
    Description : 'Details about the pixels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Pixel Information","type":"object","required":["size"],"defi'
      + 'nitions":{"pixel_size":{"items":{"description":"Length of pixel edge '
      + '[m].","type":"number","minimum":0},"description":"Size of pixels.","ty'
      + 'pe":"array","minItems":2,"maxItems":2}},"$schema":"http://json-schema.'
      + 'org/draft-04/schema#","description":"Details about the pixels '
      + 'contained in the file","properties":{"size_llcs":{"$ref":"#/definition'
      + 's/pixel_size","description":"Size of pixels in a locally levelled '
      + 'cartesian coordinate system (xy). This is only used for pixels based '
      + 'on a map projection."},"size":{"$ref":"#/definitions/pixel_size","desc'
      + 'ription":"Size of pixels in file coordinate system."}}}'
    );

    Example : (''
      + '{"size_llcs":[0.5156575252891171,0.5130835356683303],"size":[0.5971642'
      + '834779395,0.5971642834779395]}'
    );
  );

// Details about the plane patch matching process
const
  RDB_RIEGL_PLANE_PATCH_MATCHING : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_matching';
    Title       : 'Plane Patch Matching';
    Description : 'Details about the plane patch matching process';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Plane Patch Matching","type":"object","required":["plane_pat'
      + 'ch_file_one","plane_patch_file_two"],"definitions":{"file_reference":{'
      + '"description":"Reference to a plane patch '
      + 'file","properties":{"file_path":{"description":"Path of the plane '
      + 'patch file relative to the match '
      + 'file","type":"string"},"file_uuid":{"description":"Plane patch file''s '
      + 'Universally Unique Identifier (RFC 4122)","type":"string"}},"type":"ob'
      + 'ject","required":["file_uuid","file_path"]}},"$schema":"http://json-sc'
      + 'hema.org/draft-04/schema#","description":"Details about the plane '
      + 'patch matching process","properties":{"plane_patch_file_one":{"$ref":"'
      + '#/definitions/file_reference","description":"Reference to the plane '
      + 'patch file one"},"plane_patch_file_two":{"$ref":"#/definitions/file_re'
      + 'ference","description":"Reference to the plane patch file two"}}}'
    );

    Example : (''
      + '{"plane_patch_file_one":{"file_path":"Record009_Line001/191025_121410_'
      + 'Scanner_1.ptch","file_uuid":"810f5d57-eccf-49ed-b07a-0cdd109b4213"},"p'
      + 'lane_patch_file_two":{"file_path":"project.ptch","file_uuid":"fa47d509'
      + '-a64e-49ce-8b14-ff3130fbefa9"}}'
    );
  );

// Statistics about plane patches found by plane patch extractor
const
  RDB_RIEGL_PLANE_PATCH_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_statistics';
    Title       : 'Plane Patch Statistics';
    Description : 'Statistics about plane patches found by plane patch extractor';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"St'
      + 'atistics about plane patches found by plane patch '
      + 'extractor","title":"Plane Patch Statistics","type":"object","propertie'
      + 's":{"total_area":{"description":"sum of all plane patch areas [m\u00b2'
      + ']","type":"number"},"total_horizontal_area":{"description":"sum of all'
      + ' plane patch areas projected to horizontal plane '
      + '[m\u00b2]","type":"number"}}}'
    );

    Example : (''
      + '{"total_area":14007.965,"total_horizontal_area":13954.601}'
    );
  );

// Settings and classes for plane slope classification
const
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_slope_class_info';
    Title       : 'Plane Slope Class Info';
    Description : 'Settings and classes for plane slope classification';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Plane Slope Class Info","type":"object","required":["setting'
      + 's","classes"],"definitions":{"method-1":{"description":"Classification'
      + ' method 1","properties":{"maximum_inclination_angle_horizontal":{"maxi'
      + 'mum":360.0,"description":"maximum inclination angle of horizontal '
      + 'plane patches [deg]","type":"number","minimum":-360.0},"plane_classifi'
      + 'cation_method":{"maximum":1,"description":"method ID (=1)","type":"int'
      + 'eger","minimum":1}},"type":"object","required":["plane_classification_'
      + 'method","maximum_inclination_angle_horizontal"]},"method-2":{"descript'
      + 'ion":"Classification method 2","properties":{"plane_classification_met'
      + 'hod":{"maximum":2,"description":"method ID (=2)","type":"integer","min'
      + 'imum":2},"sloping_plane_classes_maximum_angle":{"maximum":360.0,"descr'
      + 'iption":"maximum inclination angle of sloping plane patches [deg]","ty'
      + 'pe":"number","minimum":-360.0},"sloping_plane_classes_minimum_angle":{'
      + '"maximum":360.0,"description":"minimum inclination angle of sloping '
      + 'plane patches [deg]","type":"number","minimum":-360.0}},"type":"object'
      + '","required":["plane_classification_method","sloping_plane_classes_min'
      + 'imum_angle","sloping_plane_classes_maximum_angle"]}},"$schema":"http:/'
      + '/json-schema.org/draft-04/schema#","description":"Settings and classes'
      + ' for plane slope classification","properties":{"classes":{"additionalP'
      + 'roperties":false,"description":"Class definition '
      + 'table","patternProperties":{"^[0-9]+$":{"description":"one field per '
      + 'class, field name is class number, field value is class name","type":"'
      + 'string"}},"type":"object"},"settings":{"description":"Classification '
      + 'settings, details see documentation of rdbplanes","type":"object","one'
      + 'Of":[{"$ref":"#/definitions/method-1"},{"$ref":"#/definitions/method-2'
      + '"}]}}}'
    );

    Example : (''
      + '{"classes":{"1":"horizontal, pointing up","3":"sloping, pointing up '
      + 'and south","11":"sloping, pointing down and south","10":"sloping, '
      + 'pointing down and east","6":"vertical, pointing east","12":"sloping, '
      + 'pointing down and north","4":"sloping, pointing up and '
      + 'north","8":"vertical, pointing north","9":"vertical, pointing '
      + 'west","5":"sloping, pointing up and west","14":"horizontal, pointing '
      + 'down","2":"sloping, pointing up and east","7":"vertical, pointing '
      + 'south","13":"sloping, pointing down and west"},"settings":{"plane_clas'
      + 'sification_method":2,"sloping_plane_classes_maximum_angle":70.0,"slopi'
      + 'ng_plane_classes_minimum_angle":10.0}}'
    );
  );

// Grouping and sorting of point attributes for visualization purposes
const
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.point_attribute_groups';
    Title       : 'Point Attribute Groups';
    Description : 'Grouping and sorting of point attributes for visualization purposes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"additionalProperties":false,"title":"Point Attribute Groups","type":'
      + '"object","$schema":"http://json-schema.org/draft-04/schema#","descript'
      + 'ion":"Grouping and sorting of point attributes for visualization '
      + 'purposes","patternProperties":{"^.*$":{"items":{"description":"Point '
      + 'attribute full name or name pattern (perl regular expression '
      + 'syntax)","type":"string"},"description":"Each field of the object '
      + 'represents a point attribute group and holds a list of point '
      + 'attributes, where the field name is the group '
      + 'name.","type":"array","minItems":1}}}'
    );

    Example : (''
      + '{"Other Attributes":["riegl.selected","riegl.visible"],"Time":["riegl.'
      + 'timestamp"],"Secondary '
      + 'Attributes":["riegl.mirror_facet","riegl.waveform_available"],"Primary'
      + ' Attributes":["riegl.reflectance","riegl.amplitude","riegl.deviation"]'
      + ',"Coordinates/Vectors":["riegl.xyz","riegl.range","riegl.theta","riegl'
      + '.phi"]}'
    );
  );

// Details about point cloud files
const
  RDB_RIEGL_POINTCLOUD_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pointcloud_info';
    Title       : 'Point Cloud Information';
    Description : 'Details about point cloud files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"De'
      + 'tails about point cloud files","title":"Point Cloud Information","type'
      + '":"object","properties":{"project":{"description":"Project name","type'
      + '":"string"},"comments":{"description":"Comments","type":"string"},"fie'
      + 'ld_of_application":{"description":"Field of application","type":"strin'
      + 'g","enum":["unknown","SLS","TLS","KLS","MLS","ULS","ALS","BLS","ILS"]}'
      + '}}'
    );

    Example : (''
      + '{"project":"Campaign 4","comments":"Line '
      + '3","field_of_application":"ALS"}'
    );
  );

// Estimated position and orientation information
const
  RDB_RIEGL_POSE_ESTIMATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_estimation';
    Title       : 'Pose Estimation';
    Description : 'Estimated position and orientation information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Pose Estimation","type":"object","required":["orientation"],'
      + '"$schema":"http://json-schema.org/draft-04/schema#","description":"Est'
      + 'imated position and orientation information as measured by GNSS, IMU '
      + 'or inclination '
      + 'sensors","properties":{"position":{"description":"Position coordinates'
      + ' and position accuracy values as measured by GNSS in the specified '
      + 'Coordinate Reference System '
      + '(CRS)","properties":{"coordinate_3":{"description":"Coordinate 3 as '
      + 'defined by axis 3 of the specified CRS (e.g., Z, Altitude)","type":"nu'
      + 'mber"},"horizontal_accuracy":{"exclusiveMinimum":true,"description":"H'
      + 'orizontal accuracy [m]","type":"number","minimum":0},"coordinate_1":{"'
      + 'description":"Coordinate 1 as defined by axis 1 of the specified CRS '
      + '(e.g., X, Latitude)","type":"number"},"vertical_accuracy":{"exclusiveM'
      + 'inimum":true,"description":"Vertical accuracy '
      + '[m]","type":"number","minimum":0},"crs":{"description":"Global '
      + 'Coordinate Reference System","properties":{"epsg":{"description":"EPSG'
      + ' '
      + 'code","type":"integer","minimum":0},"wkt":{"description":"\"Well-Known'
      + ' Text\" string, OGC WKT dialect (see http://www.opengeospatial.org/sta'
      + 'ndards/wkt-crs)","type":"string"}},"type":"object","required":["epsg"]'
      + '},"coordinate_2":{"description":"Coordinate 2 as defined by axis 2 of '
      + 'the specified CRS (e.g., Y, Longitude)","type":"number"}},"type":"obje'
      + 'ct","required":["coordinate_1","coordinate_2","coordinate_3","horizont'
      + 'al_accuracy","vertical_accuracy","crs"]},"orientation":{"description":'
      + '"Orientation values and orientation accuracies, measured with IMU or '
      + 'inclination sensors.","properties":{"yaw_accuracy":{"exclusiveMinimum"'
      + ':true,"description":"Yaw angle accuracy [deg]","type":"number","minimu'
      + 'm":0},"roll_accuracy":{"exclusiveMinimum":true,"description":"Roll '
      + 'angle accuracy [deg]","type":"number","minimum":0},"pitch":{"maximum":'
      + '360,"description":"Pitch angle about scanner Y-axis [deg]","type":"num'
      + 'ber","minimum":-360},"roll":{"maximum":360,"description":"Roll angle '
      + 'about scanner X-axis [deg]","type":"number","minimum":-360},"yaw":{"ma'
      + 'ximum":360,"description":"Yaw angle about scanner Z-axis [deg]","type"'
      + ':"number","minimum":-360},"pitch_accuracy":{"exclusiveMinimum":true,"d'
      + 'escription":"Pitch angle accuracy [deg]","type":"number","minimum":0}}'
      + ',"type":"object","required":["roll","pitch","yaw","roll_accuracy","pit'
      + 'ch_accuracy","yaw_accuracy"]},"barometric_height_amsl":{"description":'
      + '"Altitude determined based on the atmospheric pressure according to '
      + 'the standard atmosphere laws [m].","type":"number"}}}'
    );

    Example : (''
      + '{"position":{"coordinate_3":362.7124938964844,"horizontal_accuracy":0.'
      + '810699999332428,"coordinate_1":48.655799473,"vertical_accuracy":1.3314'
      + '999341964722,"crs":{"epsg":4979,"wkt":"GEOGCS[\"WGS84 / Geographic\",D'
      + 'ATUM[\"WGS84\",SPHEROID[\"WGS84\",6378137.000,298.257223563,AUTHORITY['
      + '\"EPSG\",\"7030\"]],AUTHORITY[\"EPSG\",\"6326\"]],PRIMEM[\"Greenwich\"'
      + ',0.0000000000000000,AUTHORITY[\"EPSG\",\"8901\"]],UNIT[\"Degree\",0.01'
      + '745329251994329547,AUTHORITY[\"EPSG\",\"9102\"]],AXIS[\"Latitude\",NOR'
      + 'TH],AXIS[\"Longitude\",EAST],AUTHORITY[\"EPSG\",\"4979\"]]"},"coordina'
      + 'te_2":15.645033406},"orientation":{"yaw_accuracy":1.0094337839368757,"'
      + 'roll_accuracy":0.009433783936875745,"pitch":1.509153024827064,"roll":3'
      + '.14743073066123,"yaw":101.87293630292045,"pitch_accuracy":0.0094337839'
      + '36875745},"barometric_height_amsl":386.7457796227932}'
    );
  );

// Details on position and orientation sensors
const
  RDB_RIEGL_POSE_SENSORS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_sensors';
    Title       : 'Pose Sensors';
    Description : 'Details on position and orientation sensors';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Pose Sensors","type":"object","required":["gyroscope","accel'
      + 'erometer","magnetic_field_sensor"],"definitions":{"vector":{"items":{"'
      + 'description":"Index 0=X, 1=Y, 2=Z component","type":"number"},"maxItem'
      + 's":3,"type":"array","minItems":3}},"$schema":"http://json-schema.org/d'
      + 'raft-04/schema#","description":"Details on position and orientation '
      + 'sensors","properties":{"gyroscope":{"description":"Gyroscope details",'
      + '"properties":{"unit":{"exclusiveMinimum":true,"description":"Unit of '
      + 'raw data and calibration values, 1 LSB in rad/s","type":"number","mini'
      + 'mum":0},"origin":{"$ref":"#/definitions/vector","description":"Sensor '
      + 'origin in SOCS [m] at frame angle = 0"},"relative_nonlinearity":{"$ref'
      + '":"#/definitions/vector","description":"Relative nonlinearity, dimensi'
      + 'onless"},"x_axis":{"$ref":"#/definitions/vector","description":"Sensit'
      + 'ive X axis of sensor at frame angle = '
      + '0"},"offset":{"$ref":"#/definitions/vector","description":"Value to be'
      + ' subtracted from raw measurement values"},"z_axis":{"$ref":"#/definiti'
      + 'ons/vector","description":"Sensitive Z axis of sensor at frame angle ='
      + ' 0"},"y_axis":{"$ref":"#/definitions/vector","description":"Sensitive '
      + 'Y axis of sensor at frame angle = 0"}},"type":"object","required":["un'
      + 'it","x_axis","y_axis","z_axis","offset","origin","relative_nonlinearit'
      + 'y"]},"accelerometer":{"description":"Accelerometer details","propertie'
      + 's":{"unit":{"exclusiveMinimum":true,"description":"Unit of raw data '
      + 'and calibration values, 1 LSB in 9.81 m/s\u00b2","type":"number","mini'
      + 'mum":0},"origin":{"$ref":"#/definitions/vector","description":"Sensor '
      + 'origin in SOCS [m] at frame angle = 0"},"relative_nonlinearity":{"$ref'
      + '":"#/definitions/vector","description":"Relative nonlinearity, dimensi'
      + 'onless"},"x_axis":{"$ref":"#/definitions/vector","description":"Sensit'
      + 'ive X axis of sensor at frame angle = '
      + '0"},"offset":{"$ref":"#/definitions/vector","description":"Value to be'
      + ' subtracted from raw measurement values"},"z_axis":{"$ref":"#/definiti'
      + 'ons/vector","description":"Sensitive Z axis of sensor at frame angle ='
      + ' 0"},"y_axis":{"$ref":"#/definitions/vector","description":"Sensitive '
      + 'Y axis of sensor at frame angle = 0"}},"type":"object","required":["un'
      + 'it","x_axis","y_axis","z_axis","offset","origin","relative_nonlinearit'
      + 'y"]},"magnetic_field_sensor":{"description":"Magnetic Field Sensor det'
      + 'ails","properties":{"unit":{"exclusiveMinimum":true,"description":"Uni'
      + 't of raw data and calibration values, 1 LSB in nT","type":"number","mi'
      + 'nimum":0},"fixed":{"$ref":"#/definitions/vector","description":"Distor'
      + 'tion of magnetic field caused by non-rotating scanner part"},"relative'
      + '_nonlinearity":{"$ref":"#/definitions/vector","description":"Relative '
      + 'nonlinearity, dimensionless"},"x_axis":{"$ref":"#/definitions/vector",'
      + '"description":"Sensitive X axis of sensor at frame angle = '
      + '0"},"offset":{"$ref":"#/definitions/vector","description":"Value to be'
      + ' subtracted from raw measurement values"},"z_axis":{"$ref":"#/definiti'
      + 'ons/vector","description":"Sensitive Z axis of sensor at frame angle ='
      + ' 0"},"y_axis":{"$ref":"#/definitions/vector","description":"Sensitive '
      + 'Y axis of sensor at frame angle = 0"}},"type":"object","required":["un'
      + 'it","x_axis","y_axis","z_axis","offset","fixed","relative_nonlinearity'
      + '"]}}}'
    );

    Example : (''
      + '{"gyroscope":{"unit":0.00014544410805683583,"origin":[0.02690000087022'
      + '7814,-0.03999999910593033,-0.08950000256299973],"relative_nonlinearity'
      + '":[2.888176311444113e-07,1.06274164579645e-07,-1.7186295080634935e-39]'
      + ',"x_axis":[-121.195556640625,0.8219714164733887,0.2313031703233719],"o'
      + 'ffset":[-50.92609786987305,146.15643310546875,62.4327278137207],"z_axi'
      + 's":[0.555869996547699,119.22135162353516,0.467585027217865],"y_axis":['
      + '-0.440765917301178,-0.7897399663925171,119.5894775390625]},"accelerome'
      + 'ter":{"unit":6.666666740784422e-05,"origin":[0.026900000870227814,-0.0'
      + '3999999910593033,-0.08950000256299973],"relative_nonlinearity":[0.0,0.'
      + '0,0.0],"x_axis":[-15008.123046875,56.956390380859375,-60.5175666809082'
      + '],"offset":[-733.3636474609375,58.969032287597656,1060.2550048828125],'
      + '"z_axis":[1.639882206916809,15166.744140625,-116.99742889404297],"y_ax'
      + 'is":[-7.027288913726807,-44.12333679199219,14952.3701171875]},"magneti'
      + 'c_field_sensor":{"unit":91.74311828613281,"fixed":[-1576.010498046875,'
      + '1596.081787109375,0.0],"relative_nonlinearity":[0.0,0.0,0.0],"x_axis":'
      + '[-0.011162743903696537,-2.315962774446234e-05,0.00016818844596855342],'
      + '"offset":[-23812.052734375,5606.57666015625,2493.28125],"z_axis":[0.00'
      + '041987866279669106,7.876977906562388e-05,0.011407104320824146],"y_axis'
      + '":[0.00027888521435670555,-0.011427424848079681,-5.204829722060822e-05'
      + ']}}'
    );
  );

// Laser pulse position modulation used for MTA resolution
const
  RDB_RIEGL_PULSE_POSITION_MODULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pulse_position_modulation';
    Title       : 'Pulse Position Modulation';
    Description : 'Laser pulse position modulation used for MTA resolution';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Pulse Position Modulation","type":"object","required":["leng'
      + 'th","num_mod_ampl","pulse_interval"],"$schema":"http://json-schema.org'
      + '/draft-04/schema#","description":"Laser pulse position modulation used'
      + ' for MTA resolution","properties":{"num_mod_ampl":{"maximum":255,"desc'
      + 'ription":"Number of different modulation amplitudes (2: binary modulat'
      + 'ion)","type":"integer","minimum":0},"length":{"maximum":255,"descripti'
      + 'on":"Length of code","type":"integer","minimum":0},"pulse_interval":{"'
      + 'items":{"type":"number","minimum":0},"description":"Explicit table of '
      + 'the pulse position modulation used for MTA resolution. Table gives '
      + 'times between successive laser pulses in seconds.","type":"array"},"co'
      + 'de_phase_mode":{"maximum":255,"description":"0: no synchronization, 1:'
      + ' toggle between 2 phases, 2: increment with phase_increment","type":"i'
      + 'nteger","minimum":0},"phase_step":{"maximum":255,"description":"Step '
      + 'width in phase of modulation code from line to '
      + 'line","type":"integer","minimum":0}}}'
    );

    Example : (''
      + '{"num_mod_ampl":2,"length":31,"pulse_interval":[2.759375e-06,2.759375e'
      + '-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.759375e-06,2'
      + '.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.7593'
      + '75e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875e-0'
      + '6,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.7'
      + '59375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875'
      + 'e-06,2.759375e-06,2.821875e-06],"code_phase_mode":2,"phase_step":5}'
    );
  );

// Statistics about target distance wrt. SOCS origin
const
  RDB_RIEGL_RANGE_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.range_statistics';
    Title       : 'Range Statistics';
    Description : 'Statistics about target distance wrt. SOCS origin';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Range Statistics","type":"object","required":["minimum","ave'
      + 'rage","maximum","std_dev"],"$schema":"http://json-schema.org/draft-04/'
      + 'schema#","description":"Statistics about target distance wrt. SOCS '
      + 'origin","properties":{"maximum":{"description":"Maximum '
      + 'value","type":"number"},"average":{"description":"Average '
      + 'value","type":"number"},"minimum":{"description":"Minimum '
      + 'value","type":"number"},"std_dev":{"description":"Standard '
      + 'deviation","type":"number"}}}'
    );

    Example : (''
      + '{"maximum":574.35,"average":15.49738,"minimum":0.919,"std_dev":24.349}'
    );
  );

// Receiver Internals
const
  RDB_RIEGL_RECEIVER_INTERNALS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.receiver_internals';
    Title       : 'Receiver Internals';
    Description : 'Receiver Internals';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Receiver Internals","type":"object","definitions":{"fp_table'
      + '":{"properties":{"ch":{"description":"channel number","type":"integer"'
      + ',"min":0,"max":255},"ny":{"description":"number of y entries","type":"'
      + 'integer","min":1,"max":2048},"nx":{"description":"number of x entries"'
      + ',"type":"integer","min":1,"max":2048},"tv":{"minItems":1,"type":"array'
      + '","items":{"oneOf":[{"$ref":"#/definitions/fp_table_row"},{"type":"num'
      + 'ber"}]},"maxItems":2048},"tc":{"description":"table data type code","t'
      + 'ype":"integer","min":0,"max":255}},"type":"object","desription":"scann'
      + 'er internal data","required":["ch","tc","nx","ny","tv"]},"fp":{"descri'
      + 'ption":"Fingerprint values","properties":{"s":{"items":{"items":{"type'
      + '":"number"},"maxItems":4096,"type":"array","minItems":1},"maxItems":25'
      + '6,"type":"array","minItems":1},"w":{"items":{"items":{"type":"number"}'
      + ',"maxItems":5,"type":"array","minItems":5},"maxItems":256,"type":"arra'
      + 'y","minItems":1}},"type":"object","required":["s","w"]},"fp_table_row"'
      + ':{"minItems":1,"type":"array","items":{"type":"number"},"maxItems":204'
      + '8}},"$schema":"http://json-schema.org/draft-04/schema#","description":'
      + '"Receiver '
      + 'Internals","properties":{"si":{"maximum":255,"description":"Start '
      + 'index (hw_start)","type":"number","minimum":0},"nt":{"maximum":255,"de'
      + 'scription":"Number of traces","type":"integer","minimum":0},"ns":{"max'
      + 'imum":4095,"description":"Number of samples","type":"integer","minimum'
      + '":0},"ex":{"description":"DEPRECATED, use '
      + '''riegl.exponential_decomposition'' instead","type":"object"},"t":{"addi'
      + 'tionalProperties":false,"patternProperties":{"^[0-9]+$":{"$ref":"#/def'
      + 'initions/fp","description":"one field per channel, field name is '
      + 'channel index"}},"type":"object"},"sr":{"exclusiveMinimum":true,"descr'
      + 'iption":"Sample rate [Hz]","type":"number","minimum":0},"tbl":{"items"'
      + ':{"$ref":"#/definitions/fp_table"},"description":"various internal dat'
      + 'a","type":"array","minItems":1},"mw":{"maximum":4095,"description":"Ma'
      + 'ximum weight","type":"number","minimum":0,"exclusiveMinimum":true},"a"'
      + ':{"items":{"type":"number"},"description":"Amplitude '
      + '[dB]","maxItems":256,"type":"array","minItems":1}}}'
    );

    Example : (''
      + '{"si":48,"nt":128,"ns":400,"t":{"0":{"s":[[1.23,4.56],[7.89,0.12]],"w"'
      + ':[[78,86,126,134,31],[78,86,126,134,31]]},"1":{"s":[[1.23,4.56],[7.89,'
      + '0.12]],"w":[[78,86,126,134,31],[78,86,126,134,31]]}},"sr":7959997000.0'
      + ',"tbl":[{"ch":0,"ny":2,"nx":5,"tv":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]]'
      + ',"tc":1}],"mw":31,"a":[-1.55]}'
    );
  );

// Lookup table for reflectance calculation based on amplitude and range
const
  RDB_RIEGL_REFLECTANCE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_calculation';
    Title       : 'Reflectance Calculation Table';
    Description : 'Lookup table for reflectance calculation based on amplitude and range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Reflectance Calculation Table","type":"object","required":["'
      + 'delta","content"],"$schema":"http://json-schema.org/draft-04/schema#",'
      + '"description":"Lookup table for reflectance calculation based on '
      + 'amplitude and range","properties":{"content":{"items":{"type":"number"'
      + '},"description":"Correction value [dB] to be added to the amplitude","'
      + 'maxItems":2000,"type":"array","minItems":1},"delta":{"description":"De'
      + 'lta between table entries [m], first entry is at range = 0 '
      + 'm","type":"number"}}}'
    );

    Example : (''
      + '{"content":[-33.01],"delta":0.150918}'
    );
  );

// Range-dependent and scan-angle-dependent correction of reflectance reading
const
  RDB_RIEGL_REFLECTANCE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_correction';
    Title       : 'Near-Range Reflectance Correction';
    Description : 'Range-dependent and scan-angle-dependent correction of reflectance reading';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Near-range reflectance correction","type":"object","required'
      + '":["ranges_m","line_angles_deg","reflectance_correction_db"],"$schema"'
      + ':"http://json-schema.org/draft-04/schema#","description":"Range-depend'
      + 'ent and scan-angle-dependent correction of reflectance reading","prope'
      + 'rties":{"ranges_m":{"items":{"type":"number"},"description":"Range [m]'
      + '","type":"array"},"line_angles_deg":{"items":{"type":"number"},"descri'
      + 'ption":"Angle [deg]","type":"array"},"reflectance_correction_db":{"ite'
      + 'ms":{"items":{"description":"columns (each value corresponds to an '
      + 'angle)","type":"number"},"description":"rows (each array corresponds '
      + 'to a range)","type":"array"},"description":"Near range reflectance '
      + 'correction in dB as a function of range over angle","type":"array"}}}'
    );

    Example : (''
      + '{"ranges_m":[0.0,1.0,2.0,3.0],"line_angles_deg":[0.0,0.5,1.0,1.5,1.0,2'
      + '.0,2.5,3.0,3.5,4.0],"reflectance_correction_db":[[0.8,0.7,0.6,0.5,0.4,'
      + '0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.'
      + '8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,'
      + '0.1,0.05,0.01]]}'
    );
  );

// Scan pattern description
const
  RDB_RIEGL_SCAN_PATTERN : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.scan_pattern';
    Title       : 'Scan Pattern';
    Description : 'Scan pattern description';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"definitions":{"program":{"description":"Measurement program","proper'
      + 'ties":{"laser_prr":{"exclusiveMinimum":false,"description":"Laser '
      + 'Pulse Repetition Rate '
      + '[Hz]","type":"number","minimum":0},"name":{"description":"Name of '
      + 'measurement program","type":"string"}},"type":"object","required":["na'
      + 'me"]}},"$schema":"http://json-schema.org/draft-04/schema#","descriptio'
      + 'n":"Scan pattern description","title":"Scan '
      + 'Pattern","properties":{"segments":{"description":"Segmented Line Scan '
      + 'Pattern","properties":{"list":{"items":{"description":"Line Scan Segme'
      + 'nt","properties":{"increment":{"maximum":90.0,"description":"Increment'
      + ' of angle in SOCS [deg]","type":"number","minimum":0.0},"start":{"maxi'
      + 'mum":360.0,"description":"Start angle in SOCS [deg]","type":"number","'
      + 'minimum":0.0},"stop":{"maximum":720.0,"description":"Stop angle in '
      + 'SOCS [deg]","type":"number","minimum":0.0}},"type":"object","required"'
      + ':["start","stop","increment"]},"type":"array"},"program":{"$ref":"#/de'
      + 'finitions/program"}},"type":"object","required":["list"]},"rectangular'
      + '":{"description":"Rectangular Field Of View Scan Pattern","properties"'
      + ':{"phi_start":{"maximum":360.0,"description":"Start phi angle in SOCS '
      + '[deg]","type":"number","minimum":0.0},"theta_start":{"maximum":180.0,"'
      + 'description":"Start theta angle in SOCS [deg]","type":"number","minimu'
      + 'm":0.0},"phi_stop":{"maximum":720.0,"description":"Stop phi angle in '
      + 'SOCS [deg]","type":"number","minimum":0.0},"phi_increment":{"maximum":'
      + '90.0,"description":"Increment of phi angle in SOCS [deg]","type":"numb'
      + 'er","minimum":0.0},"theta_increment":{"maximum":90.0,"description":"In'
      + 'crement of theta angle in SOCS [deg]","type":"number","minimum":0.0},"'
      + 'program":{"$ref":"#/definitions/program"},"theta_stop":{"maximum":180.'
      + '0,"description":"Stop theta angle in SOCS [deg]","type":"number","mini'
      + 'mum":0.0}},"type":"object","required":["phi_start","phi_stop","phi_inc'
      + 'rement","theta_start","theta_stop","theta_increment"]},"line":{"descri'
      + 'ption":"Line Scan Pattern","properties":{"increment":{"maximum":90.0,"'
      + 'description":"Increment of angle in SOCS [deg]","type":"number","minim'
      + 'um":0.0},"start":{"maximum":360.0,"description":"Start angle in SOCS ['
      + 'deg]","type":"number","minimum":0.0},"stop":{"maximum":720.0,"descript'
      + 'ion":"Stop angle in SOCS [deg]","type":"number","minimum":0.0},"progra'
      + 'm":{"$ref":"#/definitions/program"}},"type":"object","required":["star'
      + 't","stop","increment"]}}}'
    );

    Example : (''
      + '{"rectangular":{"phi_start":45.0,"theta_start":30.0,"phi_stop":270.0,"'
      + 'phi_increment":0.04,"theta_increment":0.04,"program":{"laser_prr":1000'
      + '00.0,"name":"High Speed"},"theta_stop":130.0}}'
    );
  );

// Details about laser shot files
const
  RDB_RIEGL_SHOT_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.shot_info';
    Title       : 'Shot Information';
    Description : 'Details about laser shot files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"De'
      + 'tails about laser shot files","title":"Shot Information","type":"objec'
      + 't","properties":{"shot_file":{"properties":{"file_extension":{"descrip'
      + 'tion":"Shot file extension, without the leading '
      + 'dot","type":"string"},"file_uuid":{"description":"File''s Universally '
      + 'Unique Identifier (RFC 4122)","type":"string"}},"type":"object","requi'
      + 'red":["file_extension"]}}}'
    );

    Example : (''
      + '{"shot_file":{"file_extension":"sodx","file_uuid":"26a00815-67c0-4bff-'
      + '8fe8-c577378fe663"}}'
    );
  );

// Point filters applied in addition to the application-defined filters
const
  RDB_RIEGL_STORED_FILTERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.stored_filters';
    Title       : 'Stored Filters';
    Description : 'Point filters applied in addition to the application-defined filters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Stored filters","type":"object","required":["activated","fil'
      + 'ters"],"$schema":"http://json-schema.org/draft-04/schema#","descriptio'
      + 'n":"Point filters applied in addition to the application-defined '
      + 'filters","properties":{"activated":{"description":"Apply (''true'') or '
      + 'ignore (''false'') all '
      + 'filters","type":"boolean"},"filters":{"items":{"description":"Point '
      + 'filter definition","properties":{"activated":{"description":"Apply '
      + '(''true'') or ignore (''false'') this '
      + 'filter","type":"boolean"},"description":{"description":"A brief '
      + 'description of the filter (e.g. for display in a '
      + 'tooltip)","type":"string"},"title":{"description":"A short filter '
      + 'title (e.g. for display in a selection '
      + 'list)","type":"string"},"filter":{"description":"The RDB filter string'
      + ' to apply (e.g. when reading points or index), details see '
      + 'documentation of function select()","type":"string"}},"type":"object",'
      + '"required":["activated","title","description","filter"]},"description"'
      + ':"List of point filters","type":"array"}}}'
    );

    Example : (''
      + '{"activated":true,"filters":[{"activated":false,"description":"Ignore '
      + 'points with uncertain MTA zone assignment","title":"Ignore uncertain '
      + 'points from MTA resolution","filter":"riegl.mta_uncertain_point == '
      + '0"},{"activated":false,"description":"Ignore points with an echo '
      + 'signal amplitude below the dynamic trigger","title":"Ignore points '
      + 'below dynamic trigger level","filter":"riegl.dyntrig_uncertain_point '
      + '== 0"},{"activated":false,"description":"Ignore points that are '
      + 'outside the outer AABB in BOCS","title":"Ignore points outside outer '
      + 'AABB","filter":"riegl.point_outside_aabb_bocs == '
      + '0"},{"activated":false,"description":"Ignore points that are inside '
      + 'the inner AABB in BOCS","title":"Ignore points inside inner '
      + 'AABB","filter":"riegl.point_inside_aabb_bocs == 0"}]}'
    );
  );

// Details of major system components like lidar sensors, cameras and navigation devices
const
  RDB_RIEGL_SYSTEM_DESCRIPTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.system_description';
    Title       : 'System Description';
    Description : 'Details of major system components like lidar sensors, cameras and navigation devices';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"System Description","type":"object","required":["$class","ve'
      + 'rsion","author","timestamp","system"],"$schema":"http://json-schema.or'
      + 'g/draft-04/schema#","description":"Details of major system components '
      + 'like lidar sensors, cameras and navigation '
      + 'devices","properties":{"$class":{"description":"Object class name","ty'
      + 'pe":"string","enum":["Document"]},"system":{"description":"The actual '
      + 'system description, details see documentation of RIEGL System '
      + 'Description","type":"object"},"timestamp":{"description":"Date and '
      + 'time of creation (e.g. 2019-06-19T13:32:10+02:00)","type":"string"},"v'
      + 'ersion":{"description":"Document format '
      + 'version","type":"string"},"author":{"description":"Name of the author '
      + 'that created the document","type":"string"}}}'
    );

    Example : (''
      + '{"$class":"Document","system":{"details":"see documentation of RIEGL '
      + 'System Description"},"timestamp":"2022-09-30T11:56:26+00:00","version"'
      + ':"1.2.1","author":"RIEGL LMS GmbH, Austria"}'
    );
  );

// Conversion of background radiation raw values to temperatures in °C
const
  RDB_RIEGL_TEMPERATURE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.temperature_calculation';
    Title       : 'Temperature Calculation Table';
    Description : 'Conversion of background radiation raw values to temperatures in °C';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Temperature Calculation Table","type":"object","definitions"'
      + ':{"conversion_table":{"properties":{"temperature":{"items":{"type":"nu'
      + 'mber"},"description":"Temperature [\u00b0C]","type":"array"},"value":{'
      + '"items":{"type":"number"},"description":"LSB [1]","type":"array"}},"ty'
      + 'pe":"object","required":["value","temperature"]}},"$schema":"http://js'
      + 'on-schema.org/draft-04/schema#","description":"Conversion of '
      + 'background radiation raw values to temperatures in \u00b0C","propertie'
      + 's":{"Si":{"$ref":"#/definitions/conversion_table","description":"Conve'
      + 'rsion table for Si channel"},"InGaAs":{"$ref":"#/definitions/conversio'
      + 'n_table","description":"Conversion table for InGaAs channel"},"InGaAs_'
      + 'Si_Difference":{"$ref":"#/definitions/conversion_table","description":'
      + '"Conversion table for InGaAs - Si difference"}}}'
    );

    Example : (''
      + '{"Si":{"temperature":[546.300048828125,548.8164051212026,551.314393850'
      + '0972,554.0144257850053,556.604252334815,559.2124464488079,561.80227299'
      + '86177,564.4104671126105,567.0002936624203],"value":[0.0,64.00097659230'
      + '323,128.0019531846065,192.0029297769097,256.0039063692129,320.00488296'
      + '151616,384.0058595538194,448.0068361461226,512.0078127384259]},"InGaAs'
      + '":{"temperature":[307.22196722535614,309.1153478247277,311.11880869150'
      + '47,313.10025350480055,315.2137946389828,317.2172555057597,319.22071637'
      + '25366,321.2021611858325,323.3157023200148],"value":[0.0,64.00097659230'
      + '323,128.0019531846065,192.0029297769097,256.0039063692129,320.00488296'
      + '151616,384.0058595538194,448.0068361461226,512.0078127384259]},"InGaAs'
      + '_Si_Difference":{"temperature":[1749.977111117893,1749.977111117893,17'
      + '49.977111117893,1749.977111117893,1749.977111117893,1749.977111117893,'
      + '1744.7813348796044,1681.9971312601092,1622.3944822534868],"value":[100'
      + '0.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400.0885036'
      + '774805,1500.0427259132668,1600.1327555162209,1700.0869777520065,1800.0'
      + '411999877924]}}'
    );
  );

// Base of timestamps (epoch)
const
  RDB_RIEGL_TIME_BASE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.time_base';
    Title       : 'Time Base';
    Description : 'Base of timestamps (epoch)';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Time Base","type":"object","required":["epoch","source"],"$s'
      + 'chema":"http://json-schema.org/draft-04/schema#","description":"Base '
      + 'of timestamps (epoch)","properties":{"epoch":{"description":"Date and '
      + 'time of timestamp ''0'' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:0'
      + '0+01:00).","type":"string"},"system":{"description":"Time system (time'
      + ' standard)","type":"string","enum":["unknown","UTC","GPS"]},"source":{'
      + '"description":"Timestamp '
      + 'source","type":"string","enum":["unknown","RTC","GNSS"]}}}'
    );

    Example : (''
      + '{"epoch":"2015-10-27T00:00:00+00:00","system":"UTC","source":"GNSS"}'
    );
  );

// Details about position+orientation files
const
  RDB_RIEGL_TRAJECTORY_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.trajectory_info';
    Title       : 'Trajectory Information';
    Description : 'Details about position+orientation files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Trajectory Information","type":"object","required":["time_in'
      + 'terval","navigation_frame"],"$schema":"http://json-schema.org/draft-04'
      + '/schema#","description":"Details about position+orientation '
      + 'files","properties":{"device":{"description":"Navigation device, e.g. '
      + 'name/type/serial","type":"string"},"settings":{"description":"Settings'
      + ' used to calculate the trajectory (descriptive '
      + 'text)","type":"string"},"project":{"description":"Project '
      + 'name","type":"string"},"field_of_application":{"description":"Field of'
      + ' application","type":"string","enum":["unknown","SLS","TLS","KLS","MLS'
      + '","ULS","ALS","BLS","ILS"]},"navigation_frame":{"description":"Navigat'
      + 'ion frame (NED: North-East-Down, ENU: East-North-Up)","type":"string",'
      + '"enum":["unknown","NED","ENU"]},"software":{"description":"Software '
      + 'that calculated the trajectory (this may be the same or different '
      + 'software than the one that created the '
      + 'file)","type":"string"},"location":{"description":"Project location, '
      + 'e.g. '
      + 'city/state/country","type":"string"},"company":{"description":"Company'
      + ' name","type":"string"},"time_interval":{"description":"Time interval '
      + 'statistics","properties":{"maximum":{"description":"Maximum time '
      + 'interval [s]","type":"number"},"average":{"description":"Average time '
      + 'interval [s]","type":"number"},"minimum":{"description":"Minimum time '
      + 'interval [s]","type":"number"},"std_dev":{"description":"Standard '
      + 'deviation of intervals [s]","type":"number"}},"type":"object","require'
      + 'd":["minimum","average","maximum","std_dev"]}}}'
    );

    Example : (''
      + '{"device":"IMU Model 12/1, Serial# '
      + '12345","settings":"default","project":"Campaign 3","field_of_applicati'
      + 'on":"MLS","navigation_frame":"NED","software":"Navigation Software '
      + 'XYZ","location":"Horn","company":"RIEGL LMS","time_interval":{"maximum'
      + '":0.005004883,"average":0.00500053,"minimum":0.00500032,"std_dev":5.51'
      + 'e-07}}'
    );
  );

// Trigger-Timestamping-Unit/IP configuration
const
  RDB_RIEGL_TTIP_CONFIGURATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.ttip_configuration';
    Title       : 'TTIP Configuration';
    Description : 'Trigger-Timestamping-Unit/IP configuration';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"TTIP Configuration","type":"object","required":["ttip_versio'
      + 'n","num_channel","ext_channel","ext_signal","ext_delay","ext_subdivide'
      + 'r","ext_bitmask","dmi_incr","dmi_min_time","dmi_max_time","dmi_dist_pe'
      + 'r_tick","channel","output_descr","input_descr","output_usage","input_u'
      + 'sage","out_polarity","out_duration","out_interval","out_delay","out_nu'
      + 'm_pulses","in_polarity","in_min_duration","in_max_duration","in_max_de'
      + 'lay"],"$schema":"http://json-schema.org/draft-04/schema#","description'
      + '":"Trigger-Timestamping-Unit/IP '
      + 'configuration","properties":{"in_polarity":{"description":"0 .. '
      + 'positive edge, 1 .. negative edge","type":"integer","minimum":0},"in_m'
      + 'ax_delay":{"description":"maximum delay to output pulse before fake '
      + 'event is generated [0.1 msec], zero indicates that no fake events are '
      + 'generated","type":"integer","minimum":0},"ext_subdivider":{"descriptio'
      + 'n":"reduces the frequency, default '
      + '1","type":"integer","minimum":0},"out_duration":{"description":"output'
      + ' pulse duration [0.1 msec]","type":"integer","minimum":0},"ext_delay":'
      + '{"description":"external trigger, time delay [0.1 msec]","type":"integ'
      + 'er","minimum":0},"ext_bitmask":{"description":"defines which of the '
      + 'internal pulse generators are to be '
      + 'started","type":"integer","minimum":0},"ext_signal":{"description":"0 '
      + '.. use input signal, 1 .. use output signal of '
      + 'channel","type":"integer","minimum":0},"dmi_incr":{"description":"dmi,'
      + ' increment in '
      + 'ticks","type":"integer"},"dmi_max_time":{"description":"dmi, maximum '
      + 'time interval between trigger events [0.1 msec]","type":"integer","min'
      + 'imum":0},"dmi_min_time":{"description":"dmi, minimum time interval '
      + 'between trigger events [0.1 msec]","type":"integer","minimum":0},"in_m'
      + 'in_duration":{"description":"input signals with smaller pulse '
      + 'durations are ignored [0.1 '
      + 'msec]","type":"integer","minimum":0},"input_usage":{"description":"0 '
      + '.. deactivated, 1 .. just detecting and timestamping","type":"integer"'
      + ',"minimum":0},"num_channel":{"description":"number of input/output cha'
      + 'nnels","type":"integer","minimum":0},"output_usage":{"description":"0 '
      + '.. no output, 1 .. output derived from internal clock, 2 .. output '
      + 'derived from dmi, 3 .. output derived from external signal, 4 .. '
      + 'output static low, 5 .. output static high","type":"integer","minimum"'
      + ':0},"output_descr":{"description":"descriptive '
      + 'string","type":"string"},"out_delay":{"description":"output pulse '
      + 'initial delay after start [0.1 msec]","type":"integer","minimum":0},"o'
      + 'ut_interval":{"description":"output pulse interval [0.1 '
      + 'msec]","type":"integer","minimum":0},"channel":{"description":"ID of '
      + 'input/output channel","type":"integer","minimum":0},"out_num_pulses":{'
      + '"description":"number of output pulses to be generated, 0 .. infinite"'
      + ',"type":"integer","minimum":0},"dmi_dist_per_tick":{"description":"dmi'
      + ', distance per tick, just informative '
      + '[m]","type":"number"},"input_descr":{"description":"descriptive '
      + 'string","type":"string"},"ttip_version":{"description":"following main'
      + '.sub.ss.sss","type":"integer","minimum":0},"ext_channel":{"description'
      + '":"ID of channel used as external trigger input, 32 indicates '
      + 'none","type":"integer","minimum":0},"out_polarity":{"description":"0 '
      + '.. positive edge, 1 .. negative edge","type":"integer","minimum":0},"i'
      + 'n_max_duration":{"description":"stops measurement of pulse duration of'
      + ' input signal [0.1 msec]","type":"integer","minimum":0}}}'
    );

    Example : (''
      + '{"in_polarity":0,"in_max_delay":9990,"ext_subdivider":1,"out_duration"'
      + ':300,"ext_delay":0,"ext_bitmask":0,"ext_signal":0,"dmi_incr":0,"dmi_ma'
      + 'x_time":0,"dmi_min_time":0,"in_min_duration":0,"input_usage":1,"num_ch'
      + 'annel":9,"output_usage":1,"output_descr":"Port 1 - Trigger","out_delay'
      + '":0,"out_interval":10000,"channel":0,"out_num_pulses":1,"dmi_dist_per_'
      + 'tick":0.0,"input_descr":"Port 1 - Exposure","ttip_version":1,"ext_chan'
      + 'nel":32,"out_polarity":0,"in_max_duration":10000}'
    );
  );

// Details about vertex file
const
  RDB_RIEGL_VERTEX_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.vertex_info';
    Title       : 'Vertex Information';
    Description : 'Details about vertex file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"De'
      + 'tails about vertex file","title":"Vertex Information","type":"object",'
      + '"properties":{"vertex_file":{"properties":{"file_extension":{"descript'
      + 'ion":"Vertex file extension, without the leading '
      + 'dot","type":"string"},"file_uuid":{"description":"File''s Universally '
      + 'Unique Identifier (RFC 4122)","type":"string"}},"type":"object","requi'
      + 'red":["file_extension"]}}}'
    );

    Example : (''
      + '{"vertex_file":{"file_extension":"vtx","file_uuid":"51534d95-d71f-4f36'
      + '-ae1a-3e63a21fd1c7"}}'
    );
  );

// Details about the voxels contained in the file
const
  RDB_RIEGL_VOXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.voxel_info';
    Title       : 'Voxel Information';
    Description : 'Details about the voxels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Voxel Information","type":"object","oneOf":[{"additionalProp'
      + 'erties":false,"properties":{"shape_thresholds":{"$ref":"#/definitions/'
      + 'shape_thresholds"},"voxel_origin":{"$ref":"#/definitions/voxel_origin_'
      + 'enum"},"size":{"description":"Size of voxels in file coordinate system'
      + '.","oneOf":[{"$ref":"#/definitions/voxel_size"},{"$ref":"#/definitions'
      + '/voxel_size_cubic"}]},"voxel_type":{"$ref":"#/definitions/voxel_type"}'
      + '},"required":["size","voxel_origin","voxel_type"]},{"additionalPropert'
      + 'ies":false,"properties":{"shape_thresholds":{"$ref":"#/definitions/sha'
      + 'pe_thresholds"},"size_llcs":{"$ref":"#/definitions/voxel_size","descri'
      + 'ption":"Size of voxels in a locally levelled cartesian coordinate '
      + 'system (xyz). This is only used for voxels based on a map projection."'
      + '},"size":{"$ref":"#/definitions/voxel_size","description":"Size of '
      + 'voxels in file coordinate system."},"voxel_origin":{"oneOf":[{"$ref":"'
      + '#/definitions/voxel_origin_enum"},{"$ref":"#/definitions/voxel_origin_'
      + 'point","description":"The base point of the voxel grid. Used together '
      + 'with <tt>voxel_size</tt> and <tt>voxel_index</tt> to compute actual '
      + 'point coordinates."}]},"reference_point":{"items":{"maximum":180,"type'
      + '":"number","minimum":-180},"description":"Point in WGS84 geodetic '
      + 'decimal degree (EPSG:4326) that was used to compute the projection '
      + 'distortion parameters. The coefficient order is latitude, longitude. '
      + 'Only voxels with corresponding geo_tag, voxel_size and reference_point'
      + ' can be reliably processed together. This entry is available for voxel'
      + ' files in projected CRS only.","maxItems":2,"type":"array","minItems":'
      + '2},"voxel_type":{"$ref":"#/definitions/voxel_type"}},"required":["refe'
      + 'rence_point","size_llcs","size","voxel_origin","voxel_type"]}],"defini'
      + 'tions":{"voxel_origin_enum":{"description":"Defines whether the '
      + 'voxel''s center or a corner is placed on CRS origin <tt>(0/0/0)</tt>.",'
      + '"enum":["center","corner"],"default":"corner"},"shape_thresholds":{"de'
      + 'scription":"Thresholds used to compute the voxel''s shape_id value.","p'
      + 'roperties":{"line":{"exclusiveMinimum":true,"description":"If the '
      + 'biggest eigenvalue is bigger than the median eigenvalue * '
      + 'line_threshold, the voxel is considered a line.","type":"number","mini'
      + 'mum":1},"plane":{"exclusiveMinimum":true,"type":"number","maximum":1,"'
      + 'description":"If the smallest eigenvalue is smaller than the median '
      + 'eigenvalue * plane_threshold, the voxel is considered a plane.","minim'
      + 'um":0,"exclusiveMaximum":true}},"type":"object","required":["plane","l'
      + 'ine"]},"voxel_origin_point":{"items":{"type":"number"},"description":"'
      + 'Origin point for all voxel indices in voxel CRS.","maxItems":3,"type":'
      + '"array","minItems":3},"voxel_size":{"items":{"$ref":"#/definitions/edg'
      + 'e_length"},"description":"Size of voxels.","maxItems":3,"type":"array"'
      + ',"minItems":3},"edge_length":{"exclusiveMinimum":true,"description":"L'
      + 'ength of voxel edge [m].","type":"number","minimum":0},"voxel_type":{"'
      + 'description":"Whether a point in a voxel represents its center or its '
      + 'centroid. If type is <tt>index</tt> there is no point but only an '
      + 'integer voxel index.","enum":["center","centroid","index"],"default":"'
      + 'centroid"},"voxel_size_cubic":{"$ref":"#/definitions/edge_length","typ'
      + 'e":"number"}},"$schema":"http://json-schema.org/draft-04/schema#","des'
      + 'cription":"Details about the voxels contained in the file"}'
    );

    Example : (''
      + '{"shape_thresholds":{"line":6,"plane":0.16},"size_llcs":[0.51565752528'
      + '91171,0.5130835356683303,0.5143705304787237],"size":[0.597164283477939'
      + '5,0.5971642834779395,0.5143705304787237],"voxel_origin":"corner","refe'
      + 'rence_point":[48,16],"voxel_type":"centroid"}'
    );
  );

// Settings for waveform averaging
const
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_averaging_settings';
    Title       : 'Waveform Averaging Settings';
    Description : 'Settings for waveform averaging';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Waveform Averaging Settings","type":"object","required":["nu'
      + 'm_shots","mta_zone"],"$schema":"http://json-schema.org/draft-04/schema'
      + '#","description":"Settings for waveform '
      + 'averaging","properties":{"mta_zone":{"description":"Fixed MTA zone for'
      + ' averaging.","type":"integer","minimum":1},"num_shots":{"description":'
      + '"Number of consecutive shots to be used for averaging.","type":"intege'
      + 'r","minimum":1},"trim":{"maximum":0.5,"description":"Percentage for '
      + 'robust averaging.","type":"number","minimum":0,"default":0}}}'
    );

    Example : (''
      + '{"mta_zone":1,"num_shots":7,"trim":0.05}'
    );
  );

// Details about waveform files
const
  RDB_RIEGL_WAVEFORM_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_info';
    Title       : 'Waveform Information';
    Description : 'Details about waveform files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Waveform Information","type":"object","required":["sample_bl'
      + 'ock_file","sample_data_files"],"$schema":"http://json-schema.org/draft'
      + '-04/schema#","description":"Details about waveform '
      + 'files","properties":{"range_offset_m":{"description":"Calibrated '
      + 'device specific range offset for waveform analysis by system response '
      + 'fitting in meters.","type":"number"},"sample_data_files":{"items":{"pr'
      + 'operties":{"sample_interval":{"exclusiveMinimum":false,"description":"'
      + 'Sampling interval in seconds","type":"number","minimum":0},"sample_bit'
      + 's":{"exclusiveMinimum":false,"type":"integer","maximum":32,"descriptio'
      + 'n":"Bitwidth of samples (e.g. 10 bit, 12 bit)","minimum":0,"exclusiveM'
      + 'aximum":false},"file_uuid":{"description":"File''s Universally Unique '
      + 'Identifier (RFC '
      + '4122)","type":"string"},"channel_name":{"description":"Sample block '
      + 'channel name","type":"string"},"delta_st":{"description":"reserved","t'
      + 'ype":"number"},"file_extension":{"description":"Sample data file '
      + 'extension, without the leading dot","type":"string"},"laser_wavelength'
      + '":{"exclusiveMinimum":false,"description":"Laser wavelength in meters '
      + '(0 = unknown)","type":"number","minimum":0},"channel":{"exclusiveMinim'
      + 'um":false,"type":"integer","maximum":255,"description":"Sample block '
      + 'channel number (255 = invalid)","minimum":0,"exclusiveMaximum":false}}'
      + ',"type":"object","required":["channel","channel_name","sample_interval'
      + '","sample_bits","laser_wavelength","delta_st","file_extension"]},"type'
      + '":"array"},"range_offset_waveform_samples_m":{"description":"Calibrate'
      + 'd device specific range offset for waveform samples in meters.","type"'
      + ':"number"},"sample_block_file":{"properties":{"file_extension":{"descr'
      + 'iption":"Sample block file extension, without the leading '
      + 'dot","type":"string"},"file_uuid":{"description":"File''s Universally '
      + 'Unique Identifier (RFC 4122)","type":"string"}},"type":"object","requi'
      + 'red":["file_extension"]}}}'
    );

    Example : (''
      + '{"range_offset_m":3.1415,"sample_data_files":[{"file_extension":"sp0",'
      + '"sample_bits":12,"file_uuid":"da084413-e3e8-4655-a122-071de8490d8e","c'
      + 'hannel_name":"high_power","delta_st":0,"sample_interval":1.00503e-09,"'
      + 'channel":0,"laser_wavelength":0},{"file_extension":"sp1","sample_bits"'
      + ':12,"file_uuid":"93585b5e-5ea9-43a1-947b-e7ba3be642d2","channel_name":'
      + '"low_power","delta_st":0,"sample_interval":1.00503e-09,"channel":1,"la'
      + 'ser_wavelength":0},{"file_extension":"sp5","sample_bits":12,"file_uuid'
      + '":"9d2298c4-1036-464f-b5cb-1cf8e517f3a0","channel_name":"wwf","delta_s'
      + 't":0,"sample_interval":1.00503e-09,"channel":5,"laser_wavelength":0}],'
      + '"range_offset_waveform_samples_m ":7.283,"sample_block_file":{"file_ex'
      + 'tension":"sbx","file_uuid":"93a03615-66c0-4bea-8ff8-c577378fe660"}}'
    );
  );

// Scanner settings for waveform output
const
  RDB_RIEGL_WAVEFORM_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_settings';
    Title       : 'Waveform Settings';
    Description : 'Scanner settings for waveform output';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"Sc'
      + 'anner settings for waveform output","title":"Waveform Settings","type"'
      + ':"array","items":{"properties":{"pass_rng_less":{"description":"Thresh'
      + 'old for range less than '
      + '[m]","type":"number"},"logic_expression":{"description":"Logic '
      + 'expression of smart waveforms '
      + 'filter","type":"string"},"channel_idx_mask":{"description":"Bit mask '
      + 'for channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = '
      + 'Bit1, ...","type":"integer"},"pass_dev_less":{"description":"Threshold'
      + ' for deviation less than '
      + '[1]","type":"integer"},"smart_enabled":{"description":"Smart waveform '
      + 'output '
      + 'enabled","type":"boolean"},"pass_ampl_less":{"description":"Threshold '
      + 'for amplitude less than '
      + '[dB]","type":"number"},"pass_rng_greater":{"description":"Threshold '
      + 'for range greater than '
      + '[m]","type":"number"},"enabled":{"description":"Waveform output enable'
      + 'd","type":"boolean"},"pass_ampl_greater":{"description":"Threshold for'
      + ' amplitude greater than '
      + '[dB]","type":"number"},"pass_dev_greater":{"description":"Threshold '
      + 'for deviation greater than '
      + '[1]","type":"integer"},"sbl_name":{"description":"Name of sample '
      + 'block, e.g.: wfm, wwf","type":"string"}},"type":"object","required":["'
      + 'sbl_name","enabled","channel_idx_mask"]}}'
    );

    Example : (''
      + '[{"pass_rng_less":13.11,"channel_idx_mask":11,"smart_enabled":true,"pa'
      + 'ss_ampl_less":5.0,"pass_rng_greater":9.27,"enabled":true,"pass_ampl_gr'
      + 'eater":1.0,"sbl_name":"wfm"},{"channel_idx_mask":32,"enabled":false,"s'
      + 'bl_name":"wwf"}]'
    );
  );

// Window analysis data estimated from scandata and resulting filter parameters
const
  RDB_RIEGL_WINDOW_ANALYSIS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_analysis';
    Title       : 'Window Analysis';
    Description : 'Window analysis data estimated from scandata and resulting filter parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Window Analysis","type":"object","required":["result","filte'
      + 'r","settings"],"$schema":"http://json-schema.org/draft-04/schema#","de'
      + 'scription":"Window analysis data estimated from scandata and resulting'
      + ' filter parameters","properties":{"filter":{"properties":{"range_min":'
      + '{"items":{"type":"number"},"description":"[m]","type":"array"},"amplit'
      + 'ude_max":{"items":{"type":"number"},"description":"[dB]","type":"array'
      + '"},"angle":{"items":{"type":"number"},"description":"[deg]","type":"ar'
      + 'ray"},"range_max":{"items":{"type":"number"},"description":"[m]","type'
      + '":"array"}},"type":"object","required":["angle","range_min","range_max'
      + '","amplitude_max"]},"result":{"properties":{"angle":{"items":{"type":"'
      + 'number"},"description":"[deg]","type":"array"},"range_sigma":{"items":'
      + '{"type":"number"},"description":"[m]","type":"array"},"amplitude_offse'
      + 't":{"items":{"type":"number"},"description":"[dB]","type":"array"},"ti'
      + 'mestamp":{"items":{"type":"number"},"description":"[s]","type":"array"'
      + '},"range_mean":{"items":{"type":"number"},"description":"[m]","type":"'
      + 'array"},"amplitude_sigma":{"items":{"type":"number"},"description":"[d'
      + 'B]","type":"array"},"amplitude_mean":{"items":{"type":"number"},"descr'
      + 'iption":"[dB]","type":"array"}},"type":"object","required":["angle","r'
      + 'ange_mean","range_sigma","amplitude_mean","amplitude_sigma","amplitude'
      + '_offset"]},"settings":{"properties":{"amplitude":{"properties":{"sigma'
      + '_factor":{"type":"number"},"additive_value":{"type":"number"}},"type":'
      + '"object","required":["sigma_factor","additive_value"]},"range":{"prope'
      + 'rties":{"sigma_factor":{"type":"number"},"additive_value":{"type":"num'
      + 'ber"}},"type":"object","required":["sigma_factor","additive_value"]}},'
      + '"type":"object","required":["range","amplitude"]}}}'
    );

    Example : (''
      + '{"filter":{"range_min":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.21'
      + '9,-0.221,-0.223,-0.225,-0.227],"amplitude_max":[8.04,8.01,7.99,7.96,7.'
      + '93,7.9,7.88,7.85,7.83,7.8,7.78],"angle":[14.9,15.0,15.1,15.2,15.3,15.4'
      + ',15.5,15.6,15.7,15.8,15.9],"range_max":[0.424,0.425,0.426,0.427,0.428,'
      + '0.428,0.429,0.43,0.431,0.431,0.432]},"result":{"angle":[14.9,15.0,15.1'
      + ',15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],"range_sigma":[0.01869652,0.'
      + '02151435,0.01747969,0.01918765,0.01945776,0.01934862,0.01955329,0.0222'
      + '5589,0.02229977,0.01899122,0.02009433],"amplitude_offset":[1.9,1.9],"t'
      + 'imestamp":[408.4441,411.4443],"range_mean":[0.1105621,0.1079564,0.1087'
      + '088,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0.1051523,0.10584'
      + '45,0.1031261],"amplitude_sigma":[0.4272844,0.4298479,0.4236816,0.42835'
      + '83,0.4362353,0.4315141,0.4373984,0.4472798,0.4346001,0.4345487,0.45406'
      + '81],"amplitude_mean":[5.347396,5.263155,5.224655,5.179926,5.097782,5.1'
      + '16479,5.051756,4.983473,5.007885,5.002441,4.982]},"settings":{"amplitu'
      + 'de":{"sigma_factor":4,"additive_value":1.0},"range":{"sigma_factor":8,'
      + '"additive_value":0.1}}}'
    );
  );

// Correction parameters for window glass echoes
const
  RDB_RIEGL_WINDOW_ECHO_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_echo_correction';
    Title       : 'Window Echo Correction';
    Description : 'Correction parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Window Echo Correction","type":"object","required":["amplitu'
      + 'de","range","slices"],"$schema":"http://json-schema.org/draft-04/schem'
      + 'a#","description":"Correction parameters for window glass '
      + 'echoes","properties":{"amplitude":{"description":"Amplitude axis of '
      + 'correction table","properties":{"maximum":{"description":"Maximum '
      + 'amplitude in '
      + 'dB","type":"number","minimum":0.0},"minimum":{"description":"Minimum '
      + 'amplitude in '
      + 'dB","type":"number","minimum":0.0},"entries":{"description":"Number of'
      + ' amplitude entries","type":"integer","minimum":1}},"type":"object","re'
      + 'quired":["minimum","maximum","entries"]},"range":{"description":"Range'
      + ' axis of correction '
      + 'table","properties":{"maximum":{"maximum":2.0,"description":"Maximum '
      + 'range in m","type":"number","minimum":-2.0},"minimum":{"maximum":2.0,"'
      + 'description":"Minimum range in '
      + 'm","type":"number","minimum":-2.0},"entries":{"description":"Number of'
      + ' range entries","type":"integer","minimum":1}},"type":"object","requir'
      + 'ed":["minimum","maximum","entries"]},"slices":{"items":{"description":'
      + '"Window echo correction parameter '
      + 'slice","properties":{"amplitude":{"description":"Window echo amplitude'
      + ' of slice in dB","type":"number"},"table":{"items":{"items":{"items":{'
      + '"description":"Table cell (item 0: amplitude in dB, 1: range in m, 2: '
      + 'flags)","type":"number"},"description":"Table column (= range '
      + 'axis)","maxItems":3,"type":"array","minItems":3},"description":"Table '
      + 'row (= amplitude '
      + 'axis)","type":"array","minItems":1},"description":"Correction table '
      + '(dimension defined by the ''amplitude'' and ''range'' objects)","type":"ar'
      + 'ray","minItems":1}},"type":"object","required":["amplitude","table"]},'
      + '"type":"array"}}}'
    );

    Example : (''
      + '{"amplitude":{"maximum":20,"minimum":2,"entries":128},"range":{"maximu'
      + 'm":1.5060822940732335,"minimum":-1.5060822940732335,"entries":128},"sl'
      + 'ices":[{"amplitude":1.5,"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]'
      + '},{"amplitude":2.0,"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]}]}'
    );
  );

// Table of all meta data item details records
const
  RDB_META_DATA_ITEMS : array of PRDBPointcloudMetaDataItemInfo = nil; // filled during initialization

implementation

procedure FixStringEncoding;
begin
  // As the unit (.pas file) doesn't contain a BOM, we need to convert all strings
  // from UTF-8 to "native" encoding at runtime (tested on Delphi 7 and Delphi XE5)

  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example)));

  RDB_RIEGL_ATMOSPHERE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Name)));
  RDB_RIEGL_ATMOSPHERE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Title)));
  RDB_RIEGL_ATMOSPHERE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Description)));
  RDB_RIEGL_ATMOSPHERE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Schema)));
  RDB_RIEGL_ATMOSPHERE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Example)));

  RDB_RIEGL_BEAM_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Name)));
  RDB_RIEGL_BEAM_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Title)));
  RDB_RIEGL_BEAM_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Description)));
  RDB_RIEGL_BEAM_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Schema)));
  RDB_RIEGL_BEAM_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Example)));

  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example)));

  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example)));

  RDB_RIEGL_DETECTION_PROBABILITY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Name)));
  RDB_RIEGL_DETECTION_PROBABILITY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Title)));
  RDB_RIEGL_DETECTION_PROBABILITY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Description)));
  RDB_RIEGL_DETECTION_PROBABILITY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Schema)));
  RDB_RIEGL_DETECTION_PROBABILITY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Example)));

  RDB_RIEGL_DEVICE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Name)));
  RDB_RIEGL_DEVICE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Title)));
  RDB_RIEGL_DEVICE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Description)));
  RDB_RIEGL_DEVICE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Schema)));
  RDB_RIEGL_DEVICE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example)));

  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example)));

  RDB_RIEGL_DEVICES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Name)));
  RDB_RIEGL_DEVICES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Title)));
  RDB_RIEGL_DEVICES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Description)));
  RDB_RIEGL_DEVICES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Schema)));
  RDB_RIEGL_DEVICES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Example)));

  RDB_RIEGL_DYNTRIG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Name)));
  RDB_RIEGL_DYNTRIG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Title)));
  RDB_RIEGL_DYNTRIG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Description)));
  RDB_RIEGL_DYNTRIG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Schema)));
  RDB_RIEGL_DYNTRIG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Example)));

  RDB_RIEGL_ECHO_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Name)));
  RDB_RIEGL_ECHO_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Title)));
  RDB_RIEGL_ECHO_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Description)));
  RDB_RIEGL_ECHO_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Schema)));
  RDB_RIEGL_ECHO_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Example)));

  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example)));

  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example)));

  RDB_RIEGL_GEO_TAG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Name)));
  RDB_RIEGL_GEO_TAG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Title)));
  RDB_RIEGL_GEO_TAG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Description)));
  RDB_RIEGL_GEO_TAG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Schema)));
  RDB_RIEGL_GEO_TAG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Example)));

  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example)));

  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example)));

  RDB_RIEGL_ITEM_NAMES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Name)));
  RDB_RIEGL_ITEM_NAMES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Title)));
  RDB_RIEGL_ITEM_NAMES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Description)));
  RDB_RIEGL_ITEM_NAMES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Schema)));
  RDB_RIEGL_ITEM_NAMES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Example)));

  RDB_RIEGL_LICENSES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Name)));
  RDB_RIEGL_LICENSES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Title)));
  RDB_RIEGL_LICENSES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Description)));
  RDB_RIEGL_LICENSES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Schema)));
  RDB_RIEGL_LICENSES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Example)));

  RDB_RIEGL_MTA_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Name)));
  RDB_RIEGL_MTA_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Title)));
  RDB_RIEGL_MTA_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Description)));
  RDB_RIEGL_MTA_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Schema)));
  RDB_RIEGL_MTA_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Example)));

  RDB_RIEGL_NEAR_RANGE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Name)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Title)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Description)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Example)));

  RDB_RIEGL_NOISE_ESTIMATES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Name)));
  RDB_RIEGL_NOISE_ESTIMATES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Title)));
  RDB_RIEGL_NOISE_ESTIMATES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Description)));
  RDB_RIEGL_NOISE_ESTIMATES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Schema)));
  RDB_RIEGL_NOISE_ESTIMATES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Example)));

  RDB_RIEGL_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Name)));
  RDB_RIEGL_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Title)));
  RDB_RIEGL_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Description)));
  RDB_RIEGL_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Schema)));
  RDB_RIEGL_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Example)));

  RDB_RIEGL_PIXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Name)));
  RDB_RIEGL_PIXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Title)));
  RDB_RIEGL_PIXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Description)));
  RDB_RIEGL_PIXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Schema)));
  RDB_RIEGL_PIXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Example)));

  RDB_RIEGL_PLANE_PATCH_MATCHING.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Name)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Title)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Description)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Schema)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Example)));

  RDB_RIEGL_PLANE_PATCH_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Name)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Title)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Description)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Example)));

  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example)));

  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example)));

  RDB_RIEGL_POINTCLOUD_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Name)));
  RDB_RIEGL_POINTCLOUD_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Title)));
  RDB_RIEGL_POINTCLOUD_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Description)));
  RDB_RIEGL_POINTCLOUD_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Schema)));
  RDB_RIEGL_POINTCLOUD_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Example)));

  RDB_RIEGL_POSE_ESTIMATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Name)));
  RDB_RIEGL_POSE_ESTIMATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Title)));
  RDB_RIEGL_POSE_ESTIMATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Description)));
  RDB_RIEGL_POSE_ESTIMATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Schema)));
  RDB_RIEGL_POSE_ESTIMATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Example)));

  RDB_RIEGL_POSE_SENSORS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Name)));
  RDB_RIEGL_POSE_SENSORS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Title)));
  RDB_RIEGL_POSE_SENSORS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Description)));
  RDB_RIEGL_POSE_SENSORS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Schema)));
  RDB_RIEGL_POSE_SENSORS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Example)));

  RDB_RIEGL_PULSE_POSITION_MODULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Name)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Title)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Description)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Schema)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Example)));

  RDB_RIEGL_RANGE_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Name)));
  RDB_RIEGL_RANGE_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Title)));
  RDB_RIEGL_RANGE_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Description)));
  RDB_RIEGL_RANGE_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Schema)));
  RDB_RIEGL_RANGE_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Example)));

  RDB_RIEGL_RECEIVER_INTERNALS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Name)));
  RDB_RIEGL_RECEIVER_INTERNALS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Title)));
  RDB_RIEGL_RECEIVER_INTERNALS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Description)));
  RDB_RIEGL_RECEIVER_INTERNALS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Schema)));
  RDB_RIEGL_RECEIVER_INTERNALS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Example)));

  RDB_RIEGL_REFLECTANCE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Name)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Title)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Description)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Schema)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Example)));

  RDB_RIEGL_REFLECTANCE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Name)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Title)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Description)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Schema)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Example)));

  RDB_RIEGL_SCAN_PATTERN.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Name)));
  RDB_RIEGL_SCAN_PATTERN.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Title)));
  RDB_RIEGL_SCAN_PATTERN.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Description)));
  RDB_RIEGL_SCAN_PATTERN.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Schema)));
  RDB_RIEGL_SCAN_PATTERN.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Example)));

  RDB_RIEGL_SHOT_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Name)));
  RDB_RIEGL_SHOT_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Title)));
  RDB_RIEGL_SHOT_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Description)));
  RDB_RIEGL_SHOT_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Schema)));
  RDB_RIEGL_SHOT_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Example)));

  RDB_RIEGL_STORED_FILTERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Name)));
  RDB_RIEGL_STORED_FILTERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Title)));
  RDB_RIEGL_STORED_FILTERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Description)));
  RDB_RIEGL_STORED_FILTERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Schema)));
  RDB_RIEGL_STORED_FILTERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Example)));

  RDB_RIEGL_SYSTEM_DESCRIPTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Name)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Title)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Description)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Schema)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Example)));

  RDB_RIEGL_TEMPERATURE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Name)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Title)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Description)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Schema)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Example)));

  RDB_RIEGL_TIME_BASE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Name)));
  RDB_RIEGL_TIME_BASE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Title)));
  RDB_RIEGL_TIME_BASE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Description)));
  RDB_RIEGL_TIME_BASE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Schema)));
  RDB_RIEGL_TIME_BASE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Example)));

  RDB_RIEGL_TRAJECTORY_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Name)));
  RDB_RIEGL_TRAJECTORY_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Title)));
  RDB_RIEGL_TRAJECTORY_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Description)));
  RDB_RIEGL_TRAJECTORY_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Schema)));
  RDB_RIEGL_TRAJECTORY_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Example)));

  RDB_RIEGL_TTIP_CONFIGURATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Name)));
  RDB_RIEGL_TTIP_CONFIGURATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Title)));
  RDB_RIEGL_TTIP_CONFIGURATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Description)));
  RDB_RIEGL_TTIP_CONFIGURATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Schema)));
  RDB_RIEGL_TTIP_CONFIGURATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Example)));

  RDB_RIEGL_VERTEX_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Name)));
  RDB_RIEGL_VERTEX_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Title)));
  RDB_RIEGL_VERTEX_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Description)));
  RDB_RIEGL_VERTEX_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Schema)));
  RDB_RIEGL_VERTEX_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Example)));

  RDB_RIEGL_VOXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Name)));
  RDB_RIEGL_VOXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Title)));
  RDB_RIEGL_VOXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Description)));
  RDB_RIEGL_VOXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Schema)));
  RDB_RIEGL_VOXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Example)));

  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example)));

  RDB_RIEGL_WAVEFORM_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Name)));
  RDB_RIEGL_WAVEFORM_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Title)));
  RDB_RIEGL_WAVEFORM_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Description)));
  RDB_RIEGL_WAVEFORM_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Schema)));
  RDB_RIEGL_WAVEFORM_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Example)));

  RDB_RIEGL_WAVEFORM_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Example)));

  RDB_RIEGL_WINDOW_ANALYSIS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Name)));
  RDB_RIEGL_WINDOW_ANALYSIS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Title)));
  RDB_RIEGL_WINDOW_ANALYSIS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Description)));
  RDB_RIEGL_WINDOW_ANALYSIS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Schema)));
  RDB_RIEGL_WINDOW_ANALYSIS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Example)));

  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example)));
end;

procedure FillMetadataArray;
var
  i : Integer;
begin
  SetLength(RDB_META_DATA_ITEMS, 52); i := -1;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ANGULAR_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ATMOSPHERE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_BEAM_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_CATALOG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DETECTION_PROBABILITY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_OUTPUT_LIMITS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DYNTRIG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ECHO_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_EXPONENTIAL_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GAUSSIAN_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEO_TAG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOMETRIC_SCALE_FACTOR;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOREFERENCING_PARAMETERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ITEM_NAMES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_LICENSES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_MTA_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NEAR_RANGE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOISE_ESTIMATES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PIXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_MATCHING;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_SLOPE_CLASS_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINT_ATTRIBUTE_GROUPS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINTCLOUD_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_ESTIMATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_SENSORS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PULSE_POSITION_MODULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RANGE_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RECEIVER_INTERNALS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SCAN_PATTERN;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SHOT_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_STORED_FILTERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SYSTEM_DESCRIPTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TEMPERATURE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TIME_BASE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TRAJECTORY_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TTIP_CONFIGURATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VERTEX_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VOXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ANALYSIS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ECHO_CORRECTION;
end;

initialization

FixStringEncoding;
FillMetadataArray;

end.
